# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .resources import Resources
    from .resources_devices_item import ResourcesDevicesItem
    from .resources_node import ResourcesNode
    from .account import Account
    from .activate_user_response import ActivateUserResponse
    from .add_on_component_source import AddOnComponentSource
    from .addon_component import AddonComponent
    from .addon_component_name import AddonComponentName
    from .addon_component_status import AddonComponentStatus
    from .ai21integrations import Ai21Integrations
    from .ai21key_auth import Ai21KeyAuth
    from .ai21model import Ai21Model
    from .ai21provider_account import Ai21ProviderAccount
    from .ai_features_settings import AiFeaturesSettings
    from .alert import Alert
    from .alert_config import AlertConfig
    from .alert_config_resource import AlertConfigResource
    from .alert_config_resource_type import AlertConfigResourceType
    from .alert_severity import AlertSeverity
    from .alert_status import AlertStatus
    from .amqp_input_config import AmqpInputConfig
    from .amqp_metric_config import AmqpMetricConfig
    from .amqp_output_config import AmqpOutputConfig
    from .anthropic_integrations import AnthropicIntegrations
    from .anthropic_key_auth import AnthropicKeyAuth
    from .anthropic_model import AnthropicModel
    from .anthropic_provider_account import AnthropicProviderAccount
    from .application import Application
    from .application_debug_info import ApplicationDebugInfo
    from .application_lifecycle_stage import ApplicationLifecycleStage
    from .application_metadata import ApplicationMetadata
    from .application_problem import ApplicationProblem
    from .application_set import ApplicationSet
    from .application_set_components_item import ApplicationSetComponentsItem
    from .application_type import ApplicationType
    from .apply_ml_entity_response import ApplyMlEntityResponse
    from .apply_ml_entity_response_data import ApplyMlEntityResponseData
    from .artifact import Artifact
    from .artifact_manifest import ArtifactManifest
    from .artifact_manifest_source import ArtifactManifestSource
    from .artifact_path import ArtifactPath
    from .artifact_type import ArtifactType
    from .artifact_version import ArtifactVersion
    from .artifacts_cache_volume import ArtifactsCacheVolume
    from .artifacts_download import ArtifactsDownload
    from .artifacts_download_artifacts_item import ArtifactsDownloadArtifactsItem
    from .assistant_message import AssistantMessage
    from .assistant_message_content import AssistantMessageContent
    from .assistant_message_content_one_item import AssistantMessageContentOneItem
    from .async_processor_sidecar import AsyncProcessorSidecar
    from .async_service import AsyncService
    from .async_service_autoscaling import AsyncServiceAutoscaling
    from .async_service_autoscaling_metrics import AsyncServiceAutoscalingMetrics
    from .async_service_replicas import AsyncServiceReplicas
    from .auto_rotate import AutoRotate
    from .autoshutdown import Autoshutdown
    from .aws_access_key_auth import AwsAccessKeyAuth
    from .aws_access_key_based_auth import AwsAccessKeyBasedAuth
    from .aws_assumed_role_based_auth import AwsAssumedRoleBasedAuth
    from .aws_bedrock_assumed_role_based_auth import AwsBedrockAssumedRoleBasedAuth
    from .aws_bedrock_guardrail_config import AwsBedrockGuardrailConfig
    from .aws_bedrock_guardrail_config_auth_data import AwsBedrockGuardrailConfigAuthData
    from .aws_bedrock_guardrail_config_operation import AwsBedrockGuardrailConfigOperation
    from .aws_bedrock_provider_account import AwsBedrockProviderAccount
    from .aws_bedrock_provider_account_auth_data import AwsBedrockProviderAccountAuthData
    from .aws_ecr import AwsEcr
    from .aws_ecr_auth_data import AwsEcrAuthData
    from .aws_eks_integration import AwsEksIntegration
    from .aws_eks_integration_auth_data import AwsEksIntegrationAuthData
    from .aws_inferentia import AwsInferentia
    from .aws_integrations import AwsIntegrations
    from .aws_parameter_store import AwsParameterStore
    from .aws_parameter_store_auth_data import AwsParameterStoreAuthData
    from .aws_provider_account import AwsProviderAccount
    from .aws_provider_account_auth_data import AwsProviderAccountAuthData
    from .aws_region import AwsRegion
    from .aws_s3 import AwsS3
    from .aws_s3auth_data import AwsS3AuthData
    from .aws_sagemaker_provider_account import AwsSagemakerProviderAccount
    from .aws_sagemaker_provider_account_auth_data import AwsSagemakerProviderAccountAuthData
    from .aws_secrets_manager import AwsSecretsManager
    from .aws_secrets_manager_auth_data import AwsSecretsManagerAuthData
    from .aws_sqs_access_key_based_auth import AwsSqsAccessKeyBasedAuth
    from .aws_sqs_assumed_role_based_auth import AwsSqsAssumedRoleBasedAuth
    from .azure_aks_integration import AzureAksIntegration
    from .azure_basic_auth import AzureBasicAuth
    from .azure_blob_storage import AzureBlobStorage
    from .azure_connection_string_auth import AzureConnectionStringAuth
    from .azure_container_registry import AzureContainerRegistry
    from .azure_content_safety_category import AzureContentSafetyCategory
    from .azure_content_safety_guardrail_config import AzureContentSafetyGuardrailConfig
    from .azure_foundry_model import AzureFoundryModel
    from .azure_foundry_provider_account import AzureFoundryProviderAccount
    from .azure_integrations import AzureIntegrations
    from .azure_key_auth import AzureKeyAuth
    from .azure_o_auth import AzureOAuth
    from .azure_open_ai_model import AzureOpenAiModel
    from .azure_open_ai_provider_account import AzureOpenAiProviderAccount
    from .azure_pii_category import AzurePiiCategory
    from .azure_pii_guardrail_config import AzurePiiGuardrailConfig
    from .azure_pii_guardrail_config_domain import AzurePiiGuardrailConfigDomain
    from .azure_provider_account import AzureProviderAccount
    from .azure_repos_integration import AzureReposIntegration
    from .azure_vault import AzureVault
    from .base_artifact_version import BaseArtifactVersion
    from .base_artifact_version_manifest import BaseArtifactVersionManifest
    from .base_autoscaling import BaseAutoscaling
    from .base_o_auth2login import BaseOAuth2Login
    from .base_o_auth2login_jwt_source import BaseOAuth2LoginJwtSource
    from .base_service import BaseService
    from .base_service_image import BaseServiceImage
    from .base_service_mounts_item import BaseServiceMountsItem
    from .base_workbench_input import BaseWorkbenchInput
    from .base_workbench_input_mounts_item import BaseWorkbenchInputMountsItem
    from .basic_auth_creds import BasicAuthCreds
    from .bedrock_model import BedrockModel
    from .bitbucket_integration import BitbucketIntegration
    from .bitbucket_provider_account import BitbucketProviderAccount
    from .blob_storage_reference import BlobStorageReference
    from .blue_green import BlueGreen
    from .budget_alert import BudgetAlert
    from .budget_config import BudgetConfig
    from .budget_limit_unit import BudgetLimitUnit
    from .budget_rule import BudgetRule
    from .budget_when import BudgetWhen
    from .build import Build
    from .build_build_source import BuildBuildSource
    from .build_build_spec import BuildBuildSpec
    from .build_info import BuildInfo
    from .build_status import BuildStatus
    from .canary import Canary
    from .canary_step import CanaryStep
    from .cerebras_integrations import CerebrasIntegrations
    from .cerebras_key_auth import CerebrasKeyAuth
    from .cerebras_model import CerebrasModel
    from .cerebras_provider_account import CerebrasProviderAccount
    from .change_password_response import ChangePasswordResponse
    from .chat_prompt_manifest import ChatPromptManifest
    from .chat_prompt_manifest_mcp_servers_item import ChatPromptManifestMcpServersItem
    from .chat_prompt_manifest_messages_item import ChatPromptManifestMessagesItem
    from .chat_prompt_manifest_response_format import ChatPromptManifestResponseFormat
    from .chat_prompt_manifest_routing_config import ChatPromptManifestRoutingConfig
    from .cloudera_integrations import ClouderaIntegrations
    from .cloudera_model import ClouderaModel
    from .cloudera_provider_account import ClouderaProviderAccount
    from .cloudera_provider_account_auth_data import ClouderaProviderAccountAuthData
    from .cloudera_token_auth import ClouderaTokenAuth
    from .cloudera_workload_auth_token import ClouderaWorkloadAuthToken
    from .cluster import Cluster
    from .cluster_gateway import ClusterGateway
    from .cluster_manifest import ClusterManifest
    from .cluster_manifest_cluster_type import ClusterManifestClusterType
    from .cluster_manifest_monitoring import ClusterManifestMonitoring
    from .cluster_manifest_node_label_keys import ClusterManifestNodeLabelKeys
    from .cluster_manifest_workbench_config import ClusterManifestWorkbenchConfig
    from .cluster_type import ClusterType
    from .codeserver import Codeserver
    from .cohere_integrations import CohereIntegrations
    from .cohere_key_auth import CohereKeyAuth
    from .cohere_model import CohereModel
    from .cohere_provider_account import CohereProviderAccount
    from .collaborator import Collaborator
    from .common_tools_settings import CommonToolsSettings
    from .config import Config
    from .container_task_config import ContainerTaskConfig
    from .container_task_config_image import ContainerTaskConfigImage
    from .container_task_config_mounts_item import ContainerTaskConfigMountsItem
    from .core_nats_output_config import CoreNatsOutputConfig
    from .cpu_utilization_metric import CpuUtilizationMetric
    from .create_multi_part_upload_request import CreateMultiPartUploadRequest
    from .create_personal_access_token_response import CreatePersonalAccessTokenResponse
    from .cron_metric import CronMetric
    from .custom_basic_auth import CustomBasicAuth
    from .custom_bearer_auth import CustomBearerAuth
    from .custom_blob_storage import CustomBlobStorage
    from .custom_guardrail_config import CustomGuardrailConfig
    from .custom_guardrail_config_auth_data import CustomGuardrailConfigAuthData
    from .custom_guardrail_config_operation import CustomGuardrailConfigOperation
    from .custom_guardrail_config_target import CustomGuardrailConfigTarget
    from .custom_helm_repo import CustomHelmRepo
    from .custom_integrations import CustomIntegrations
    from .custom_jwt_auth_integration import CustomJwtAuthIntegration
    from .custom_provider_account import CustomProviderAccount
    from .custom_tls_settings import CustomTlsSettings
    from .custom_username_password_artifacts_registry import CustomUsernamePasswordArtifactsRegistry
    from .data_directory import DataDirectory
    from .data_directory_manifest import DataDirectoryManifest
    from .data_directory_manifest_source import DataDirectoryManifestSource
    from .databricks_api_key_auth import DatabricksApiKeyAuth
    from .databricks_integrations import DatabricksIntegrations
    from .databricks_model import DatabricksModel
    from .databricks_provider_account import DatabricksProviderAccount
    from .databricks_provider_account_auth_data import DatabricksProviderAccountAuthData
    from .databricks_service_principal_auth import DatabricksServicePrincipalAuth
    from .deactivate_user_response import DeactivateUserResponse
    from .deepinfra_integrations import DeepinfraIntegrations
    from .deepinfra_key_auth import DeepinfraKeyAuth
    from .deepinfra_model import DeepinfraModel
    from .deepinfra_provider_account import DeepinfraProviderAccount
    from .delete_application_response import DeleteApplicationResponse
    from .delete_job_run_response import DeleteJobRunResponse
    from .delete_personal_access_token_response import DeletePersonalAccessTokenResponse
    from .delete_secret_group_response import DeleteSecretGroupResponse
    from .delete_team_response import DeleteTeamResponse
    from .delete_user_response import DeleteUserResponse
    from .delete_virtual_account_response import DeleteVirtualAccountResponse
    from .deployment import Deployment
    from .deployment_build import DeploymentBuild
    from .deployment_manifest import DeploymentManifest
    from .deployment_status import DeploymentStatus
    from .deployment_status_value import DeploymentStatusValue
    from .deployment_transition import DeploymentTransition
    from .developer_message import DeveloperMessage
    from .developer_message_content import DeveloperMessageContent
    from .docker_file_build import DockerFileBuild
    from .docker_file_build_command import DockerFileBuildCommand
    from .dockerhub_basic_auth import DockerhubBasicAuth
    from .dockerhub_integrations import DockerhubIntegrations
    from .dockerhub_provider_account import DockerhubProviderAccount
    from .dockerhub_registry import DockerhubRegistry
    from .dynamic_volume_config import DynamicVolumeConfig
    from .email import Email
    from .email_notification_channel import EmailNotificationChannel
    from .empty_response import EmptyResponse
    from .endpoint import Endpoint
    from .enkrypt_ai_guardrail_config import EnkryptAiGuardrailConfig
    from .enkrypt_ai_guardrail_config_operation import EnkryptAiGuardrailConfigOperation
    from .enkrypt_ai_key_auth import EnkryptAiKeyAuth
    from .environment import Environment
    from .environment_color import EnvironmentColor
    from .environment_manifest import EnvironmentManifest
    from .environment_optimize_for import EnvironmentOptimizeFor
    from .event import Event
    from .event_chart import EventChart
    from .event_chart_category import EventChartCategory
    from .event_involved_object import EventInvolvedObject
    from .external_blob_storage_source import ExternalBlobStorageSource
    from .fast_ai_framework import FastAiFramework
    from .fiddler_guard_type import FiddlerGuardType
    from .fiddler_guardrail_config import FiddlerGuardrailConfig
    from .fiddler_key_auth import FiddlerKeyAuth
    from .file_info import FileInfo
    from .flyte_launch_plan import FlyteLaunchPlan
    from .flyte_launch_plan_id import FlyteLaunchPlanId
    from .flyte_launch_plan_spec import FlyteLaunchPlanSpec
    from .flyte_task import FlyteTask
    from .flyte_task_custom import FlyteTaskCustom
    from .flyte_task_custom_truefoundry import FlyteTaskCustomTruefoundry
    from .flyte_task_id import FlyteTaskId
    from .flyte_task_template import FlyteTaskTemplate
    from .flyte_workflow import FlyteWorkflow
    from .flyte_workflow_id import FlyteWorkflowId
    from .flyte_workflow_template import FlyteWorkflowTemplate
    from .forward_action import ForwardAction
    from .function import Function
    from .function_schema import FunctionSchema
    from .gateway_config import GatewayConfig
    from .gateway_configuration import GatewayConfiguration
    from .gateway_otel_config import GatewayOtelConfig
    from .gateway_otel_config_otel_traces_exporter_config import GatewayOtelConfigOtelTracesExporterConfig
    from .gateway_request_metadata_filter import GatewayRequestMetadataFilter
    from .gateway_request_metadata_filter_operator import GatewayRequestMetadataFilterOperator
    from .gateway_request_metadata_filter_value import GatewayRequestMetadataFilterValue
    from .gcp_api_key_auth import GcpApiKeyAuth
    from .gcp_gcr import GcpGcr
    from .gcp_gcs import GcpGcs
    from .gcp_gke_integration import GcpGkeIntegration
    from .gcp_gsm import GcpGsm
    from .gcp_integrations import GcpIntegrations
    from .gcp_key_file_auth import GcpKeyFileAuth
    from .gcp_provider_account import GcpProviderAccount
    from .gcp_region import GcpRegion
    from .gcp_tpu import GcpTpu
    from .gemini_model import GeminiModel
    from .get_alerts_response import GetAlertsResponse
    from .get_application_deployment_response import GetApplicationDeploymentResponse
    from .get_application_response import GetApplicationResponse
    from .get_artifact_response import GetArtifactResponse
    from .get_artifact_version_response import GetArtifactVersionResponse
    from .get_authenticated_vcsurl_response import GetAuthenticatedVcsurlResponse
    from .get_auto_provisioning_state_response import GetAutoProvisioningStateResponse
    from .get_charts_response import GetChartsResponse
    from .get_cluster_response import GetClusterResponse
    from .get_data_directory_response import GetDataDirectoryResponse
    from .get_environment_response import GetEnvironmentResponse
    from .get_events_response import GetEventsResponse
    from .get_job_run_response import GetJobRunResponse
    from .get_logs_response import GetLogsResponse
    from .get_ml_repo_response import GetMlRepoResponse
    from .get_model_response import GetModelResponse
    from .get_model_version_response import GetModelVersionResponse
    from .get_or_create_personal_access_token_response import GetOrCreatePersonalAccessTokenResponse
    from .get_prompt_response import GetPromptResponse
    from .get_prompt_version_response import GetPromptVersionResponse
    from .get_secret_group_response import GetSecretGroupResponse
    from .get_secret_response import GetSecretResponse
    from .get_signed_ur_ls_request import GetSignedUrLsRequest
    from .get_signed_ur_ls_response import GetSignedUrLsResponse
    from .get_suggested_deployment_endpoint_response import GetSuggestedDeploymentEndpointResponse
    from .get_team_response import GetTeamResponse
    from .get_token_for_virtual_account_response import GetTokenForVirtualAccountResponse
    from .get_user_resources_response import GetUserResourcesResponse
    from .get_user_response import GetUserResponse
    from .get_user_teams_response import GetUserTeamsResponse
    from .get_virtual_account_response import GetVirtualAccountResponse
    from .get_workspace_response import GetWorkspaceResponse
    from .git_helm_repo import GitHelmRepo
    from .git_repository_exists_response import GitRepositoryExistsResponse
    from .git_source import GitSource
    from .github_integration import GithubIntegration
    from .github_provider_account import GithubProviderAccount
    from .gitlab_integration import GitlabIntegration
    from .gitlab_provider_account import GitlabProviderAccount
    from .gluon_framework import GluonFramework
    from .google_gemini_provider_account import GoogleGeminiProviderAccount
    from .google_vertex_provider_account import GoogleVertexProviderAccount
    from .graph import Graph
    from .graph_chart_type import GraphChartType
    from .groq_integrations import GroqIntegrations
    from .groq_key_auth import GroqKeyAuth
    from .groq_model import GroqModel
    from .groq_provider_account import GroqProviderAccount
    from .guardrail_config_group import GuardrailConfigGroup
    from .guardrail_config_integrations import GuardrailConfigIntegrations
    from .guardrails import Guardrails
    from .guardrails_config import GuardrailsConfig
    from .guardrails_rule import GuardrailsRule
    from .guardrails_when import GuardrailsWhen
    from .h2o_framework import H2OFramework
    from .hashicorp_integrations import HashicorpIntegrations
    from .hashicorp_provider_account import HashicorpProviderAccount
    from .hashicorp_token_auth import HashicorpTokenAuth
    from .hashicorp_vault_integration import HashicorpVaultIntegration
    from .header_match import HeaderMatch
    from .header_routing_config import HeaderRoutingConfig
    from .health_probe import HealthProbe
    from .helm import Helm
    from .helm_repo import HelmRepo
    from .helm_source import HelmSource
    from .http_error import HttpError
    from .http_error_code import HttpErrorCode
    from .http_probe import HttpProbe
    from .http_validation_error import HttpValidationError
    from .huggingface_artifact_source import HuggingfaceArtifactSource
    from .i_change import IChange
    from .i_change_operation import IChangeOperation
    from .image import Image
    from .image_command import ImageCommand
    from .image_content_part import ImageContentPart
    from .image_content_part_image_url import ImageContentPartImageUrl
    from .image_content_part_image_url_url import ImageContentPartImageUrlUrl
    from .infer_method_name import InferMethodName
    from .infra_provider_account import InfraProviderAccount
    from .ingress_controller_config import IngressControllerConfig
    from .input_output_based_cost_metric_value import InputOutputBasedCostMetricValue
    from .intercept import Intercept
    from .intercept_rules_item import InterceptRulesItem
    from .intercept_rules_item_action import InterceptRulesItemAction
    from .internal_artifact_version import InternalArtifactVersion
    from .internal_list_artifact_versions_response import InternalListArtifactVersionsResponse
    from .internal_list_artifact_versions_response_data_item import InternalListArtifactVersionsResponseDataItem
    from .internal_model_version import InternalModelVersion
    from .invite_user_response import InviteUserResponse
    from .is_cluster_connected_response import IsClusterConnectedResponse
    from .j_frog_integrations import JFrogIntegrations
    from .jfrog_artifacts_registry import JfrogArtifactsRegistry
    from .jfrog_basic_auth import JfrogBasicAuth
    from .jfrog_provider_account import JfrogProviderAccount
    from .job import Job
    from .job_alert import JobAlert
    from .job_image import JobImage
    from .job_mounts_item import JobMountsItem
    from .job_run import JobRun
    from .job_run_status import JobRunStatus
    from .job_runs_sort_by import JobRunsSortBy
    from .job_trigger import JobTrigger
    from .job_trigger_input import JobTriggerInput
    from .job_trigger_input_command import JobTriggerInputCommand
    from .json_object_response_format import JsonObjectResponseFormat
    from .json_schema import JsonSchema
    from .json_schema_response_format import JsonSchemaResponseFormat
    from .jwt import Jwt
    from .jwt_auth_config import JwtAuthConfig
    from .jwt_auth_config_claims_item import JwtAuthConfigClaimsItem
    from .kafka_input_config import KafkaInputConfig
    from .kafka_metric_config import KafkaMetricConfig
    from .kafka_output_config import KafkaOutputConfig
    from .kafka_sasl_auth import KafkaSaslAuth
    from .keras_framework import KerasFramework
    from .kustomize import Kustomize
    from .latency_based_load_balance_target import LatencyBasedLoadBalanceTarget
    from .latency_based_load_balancing import LatencyBasedLoadBalancing
    from .latency_based_load_balancing_rule import LatencyBasedLoadBalancingRule
    from .library_name import LibraryName
    from .light_gbm_framework import LightGbmFramework
    from .list_application_deployments_response import ListApplicationDeploymentsResponse
    from .list_applications_response import ListApplicationsResponse
    from .list_artifact_versions_response import ListArtifactVersionsResponse
    from .list_artifacts_response import ListArtifactsResponse
    from .list_cluster_addons_response import ListClusterAddonsResponse
    from .list_clusters_response import ListClustersResponse
    from .list_data_directories_response import ListDataDirectoriesResponse
    from .list_environments_response import ListEnvironmentsResponse
    from .list_files_request import ListFilesRequest
    from .list_files_response import ListFilesResponse
    from .list_job_run_response import ListJobRunResponse
    from .list_ml_repos_response import ListMlReposResponse
    from .list_model_versions_response import ListModelVersionsResponse
    from .list_models_response import ListModelsResponse
    from .list_personal_access_token_response import ListPersonalAccessTokenResponse
    from .list_prompt_versions_response import ListPromptVersionsResponse
    from .list_prompts_response import ListPromptsResponse
    from .list_secret_group_response import ListSecretGroupResponse
    from .list_secrets_response import ListSecretsResponse
    from .list_teams_response import ListTeamsResponse
    from .list_users_response import ListUsersResponse
    from .list_virtual_account_response import ListVirtualAccountResponse
    from .list_workspaces_response import ListWorkspacesResponse
    from .load_balance_target import LoadBalanceTarget
    from .load_balancing_config import LoadBalancingConfig
    from .load_balancing_rule import LoadBalancingRule
    from .load_balancing_when import LoadBalancingWhen
    from .local_artifact_source import LocalArtifactSource
    from .local_model_source import LocalModelSource
    from .local_source import LocalSource
    from .log import Log
    from .logs_filter_query import LogsFilterQuery
    from .logs_filter_query_type import LogsFilterQueryType
    from .logs_response import LogsResponse
    from .logs_search_filter_type import LogsSearchFilterType
    from .logs_search_operator_type import LogsSearchOperatorType
    from .logs_sorting_direction import LogsSortingDirection
    from .manual import Manual
    from .mcp_server_auth import McpServerAuth
    from .mcp_server_header_auth import McpServerHeaderAuth
    from .mcp_server_header_override_auth import McpServerHeaderOverrideAuth
    from .mcp_server_integration import McpServerIntegration
    from .mcp_server_integration_transport import McpServerIntegrationTransport
    from .mcp_server_integrations import McpServerIntegrations
    from .mcp_server_o_auth2 import McpServerOAuth2
    from .mcp_server_o_auth2jwt_source import McpServerOAuth2JwtSource
    from .mcp_server_passthrough import McpServerPassthrough
    from .mcp_server_provider_account import McpServerProviderAccount
    from .mcp_server_tool_details import McpServerToolDetails
    from .mcp_server_with_fqn import McpServerWithFqn
    from .mcp_server_with_url import McpServerWithUrl
    from .mcp_tool import McpTool
    from .metadata import Metadata
    from .metric import Metric
    from .mime_type import MimeType
    from .mirror_action import MirrorAction
    from .mistral_ai_integrations import MistralAiIntegrations
    from .mistral_ai_key_auth import MistralAiKeyAuth
    from .mistral_ai_model import MistralAiModel
    from .mistral_ai_provider_account import MistralAiProviderAccount
    from .ml_repo import MlRepo
    from .ml_repo_manifest import MlRepoManifest
    from .model import Model
    from .model_configuration import ModelConfiguration
    from .model_cost_metric import ModelCostMetric
    from .model_manifest import ModelManifest
    from .model_manifest_framework import ModelManifestFramework
    from .model_manifest_source import ModelManifestSource
    from .model_provider_account import ModelProviderAccount
    from .model_type import ModelType
    from .model_version import ModelVersion
    from .model_version_environment import ModelVersionEnvironment
    from .multi_part_upload import MultiPartUpload
    from .multi_part_upload_response import MultiPartUploadResponse
    from .multi_part_upload_storage_provider import MultiPartUploadStorageProvider
    from .nats_input_config import NatsInputConfig
    from .nats_metric_config import NatsMetricConfig
    from .nats_output_config import NatsOutputConfig
    from .nats_user_password_auth import NatsUserPasswordAuth
    from .node_selector import NodeSelector
    from .node_selector_capacity_type import NodeSelectorCapacityType
    from .nodepool import Nodepool
    from .nodepool_selector import NodepoolSelector
    from .nomic_integrations import NomicIntegrations
    from .nomic_key_auth import NomicKeyAuth
    from .nomic_model import NomicModel
    from .nomic_provider_account import NomicProviderAccount
    from .non_negative_float import NonNegativeFloat
    from .notebook import Notebook
    from .notebook_config import NotebookConfig
    from .notification_target import NotificationTarget
    from .notification_target_for_alert_rule import NotificationTargetForAlertRule
    from .nvidia_gpu import NvidiaGpu
    from .nvidia_miggpu import NvidiaMiggpu
    from .nvidia_miggpu_profile import NvidiaMiggpuProfile
    from .nvidia_timeslicing_gpu import NvidiaTimeslicingGpu
    from .o_auth2login_provider import OAuth2LoginProvider
    from .oci_repo import OciRepo
    from .ollama_integrations import OllamaIntegrations
    from .ollama_key_auth import OllamaKeyAuth
    from .ollama_model import OllamaModel
    from .ollama_provider_account import OllamaProviderAccount
    from .onnx_framework import OnnxFramework
    from .open_ai_integrations import OpenAiIntegrations
    from .open_ai_model import OpenAiModel
    from .open_ai_moderations_guardrail_config import OpenAiModerationsGuardrailConfig
    from .open_ai_moderations_guardrail_config_category_thresholds_value import (
        OpenAiModerationsGuardrailConfigCategoryThresholdsValue,
    )
    from .open_ai_moderations_guardrail_config_category_thresholds_value_harassment import (
        OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment,
    )
    from .open_router_api_key_auth import OpenRouterApiKeyAuth
    from .open_router_integrations import OpenRouterIntegrations
    from .open_router_model import OpenRouterModel
    from .open_router_provider_account import OpenRouterProviderAccount
    from .openai_api_key_auth import OpenaiApiKeyAuth
    from .openai_provider_account import OpenaiProviderAccount
    from .operation import Operation
    from .otel_exporter_grpc_config import OtelExporterGrpcConfig
    from .otel_exporter_http_config import OtelExporterHttpConfig
    from .otel_exporter_http_config_encoding import OtelExporterHttpConfigEncoding
    from .owned_by import OwnedBy
    from .paddle_framework import PaddleFramework
    from .pager_duty import PagerDuty
    from .pager_duty_integration import PagerDutyIntegration
    from .pager_duty_integration_key_auth import PagerDutyIntegrationKeyAuth
    from .pager_duty_integrations import PagerDutyIntegrations
    from .pager_duty_provider_account import PagerDutyProviderAccount
    from .pagination import Pagination
    from .palm_integrations import PalmIntegrations
    from .palm_key_auth import PalmKeyAuth
    from .palm_model import PalmModel
    from .palm_provider_account import PalmProviderAccount
    from .palo_alto_prisma_airs_guardrail_config import PaloAltoPrismaAirsGuardrailConfig
    from .palo_alto_prisma_airs_guardrail_config_mode import PaloAltoPrismaAirsGuardrailConfigMode
    from .palo_alto_prisma_airs_key_auth import PaloAltoPrismaAirsKeyAuth
    from .pangea_guard_type import PangeaGuardType
    from .pangea_guardrail_config import PangeaGuardrailConfig
    from .pangea_guardrail_config_operation import PangeaGuardrailConfigOperation
    from .pangea_key_auth import PangeaKeyAuth
    from .param import Param
    from .param_param_type import ParamParamType
    from .parameters import Parameters
    from .parameters_stop import ParametersStop
    from .patronus_answer_relevance_criteria import PatronusAnswerRelevanceCriteria
    from .patronus_answer_relevance_evaluator import PatronusAnswerRelevanceEvaluator
    from .patronus_evaluator import PatronusEvaluator
    from .patronus_glider_criteria import PatronusGliderCriteria
    from .patronus_glider_evaluator import PatronusGliderEvaluator
    from .patronus_guardrail_config import PatronusGuardrailConfig
    from .patronus_guardrail_config_target import PatronusGuardrailConfigTarget
    from .patronus_judge_criteria import PatronusJudgeCriteria
    from .patronus_judge_evaluator import PatronusJudgeEvaluator
    from .patronus_key_auth import PatronusKeyAuth
    from .patronus_phi_criteria import PatronusPhiCriteria
    from .patronus_phi_evaluator import PatronusPhiEvaluator
    from .patronus_pii_criteria import PatronusPiiCriteria
    from .patronus_pii_evaluator import PatronusPiiEvaluator
    from .patronus_toxicity_criteria import PatronusToxicityCriteria
    from .patronus_toxicity_evaluator import PatronusToxicityEvaluator
    from .per_thousand_embedding_tokens_cost_metric import PerThousandEmbeddingTokensCostMetric
    from .per_thousand_tokens_cost_metric import PerThousandTokensCostMetric
    from .permissions import Permissions
    from .perplexity_ai_key_auth import PerplexityAiKeyAuth
    from .perplexity_ai_model import PerplexityAiModel
    from .perplexity_ai_provider_account import PerplexityAiProviderAccount
    from .perplexity_integrations import PerplexityIntegrations
    from .personal_access_token_manifest import PersonalAccessTokenManifest
    from .pip import Pip
    from .poetry import Poetry
    from .policy_actions import PolicyActions
    from .policy_entity_types import PolicyEntityTypes
    from .policy_filters import PolicyFilters
    from .policy_manifest import PolicyManifest
    from .policy_manifest_mode import PolicyManifestMode
    from .policy_manifest_operation import PolicyManifestOperation
    from .policy_mutation_operation import PolicyMutationOperation
    from .policy_validation_operation import PolicyValidationOperation
    from .port import Port
    from .port_app_protocol import PortAppProtocol
    from .port_auth import PortAuth
    from .port_protocol import PortProtocol
    from .presigned_url_object import PresignedUrlObject
    from .priority_based_load_balance_target import PriorityBasedLoadBalanceTarget
    from .priority_based_load_balancing import PriorityBasedLoadBalancing
    from .priority_based_load_balancing_rule import PriorityBasedLoadBalancingRule
    from .prometheus_alert_rule import PrometheusAlertRule
    from .prompt import Prompt
    from .prompt_foo_guard_type import PromptFooGuardType
    from .prompt_foo_guardrail_config import PromptFooGuardrailConfig
    from .prompt_foo_guardrail_config_operation import PromptFooGuardrailConfigOperation
    from .prompt_version import PromptVersion
    from .provider_accounts import ProviderAccounts
    from .public_cost_metric import PublicCostMetric
    from .py_spark_task_config import PySparkTaskConfig
    from .py_torch_framework import PyTorchFramework
    from .python_build import PythonBuild
    from .python_build_command import PythonBuildCommand
    from .python_build_python_dependencies import PythonBuildPythonDependencies
    from .python_task_config import PythonTaskConfig
    from .python_task_config_image import PythonTaskConfigImage
    from .python_task_config_mounts_item import PythonTaskConfigMountsItem
    from .quay_artifacts_registry import QuayArtifactsRegistry
    from .quay_basic_auth import QuayBasicAuth
    from .quay_integrations import QuayIntegrations
    from .quay_provider_account import QuayProviderAccount
    from .query_spans_response import QuerySpansResponse
    from .r_studio import RStudio
    from .rate_limit_config import RateLimitConfig
    from .rate_limit_rule import RateLimitRule
    from .rate_limit_unit import RateLimitUnit
    from .rate_limit_when import RateLimitWhen
    from .recommendation import Recommendation
    from .refusal_content_part import RefusalContentPart
    from .register_users_response import RegisterUsersResponse
    from .remote_source import RemoteSource
    from .retry_config import RetryConfig
    from .revoke_all_personal_access_token_response import RevokeAllPersonalAccessTokenResponse
    from .role_manifest import RoleManifest
    from .role_permissions import RolePermissions
    from .rolling import Rolling
    from .rps_metric import RpsMetric
    from .sagemaker_model import SagemakerModel
    from .samba_nova_integrations import SambaNovaIntegrations
    from .samba_nova_key_auth import SambaNovaKeyAuth
    from .samba_nova_model import SambaNovaModel
    from .samba_nova_provider_account import SambaNovaProviderAccount
    from .schedule import Schedule
    from .schedule_concurrency_policy import ScheduleConcurrencyPolicy
    from .secret import Secret
    from .secret_group import SecretGroup
    from .secret_group_manifest import SecretGroupManifest
    from .secret_input import SecretInput
    from .secret_mount import SecretMount
    from .secret_store_config import SecretStoreConfig
    from .secret_version import SecretVersion
    from .self_hosted_model import SelfHostedModel
    from .self_hosted_model_auth_data import SelfHostedModelAuthData
    from .self_hosted_model_integrations import SelfHostedModelIntegrations
    from .self_hosted_model_model_server import SelfHostedModelModelServer
    from .self_hosted_model_provider_account import SelfHostedModelProviderAccount
    from .service import Service
    from .service_autoscaling import ServiceAutoscaling
    from .service_autoscaling_metrics import ServiceAutoscalingMetrics
    from .service_replicas import ServiceReplicas
    from .service_rollout_strategy import ServiceRolloutStrategy
    from .session import Session
    from .signed_url import SignedUrl
    from .sklearn_framework import SklearnFramework
    from .sklearn_model_schema import SklearnModelSchema
    from .sklearn_serialization_format import SklearnSerializationFormat
    from .sla_cutoff import SlaCutoff
    from .slack_bot import SlackBot
    from .slack_bot_auth import SlackBotAuth
    from .slack_bot_integration import SlackBotIntegration
    from .slack_integrations import SlackIntegrations
    from .slack_provider_account import SlackProviderAccount
    from .slack_webhook import SlackWebhook
    from .slack_webhook_auth import SlackWebhookAuth
    from .slack_webhook_integration import SlackWebhookIntegration
    from .smtp_credentials import SmtpCredentials
    from .snowflake_cortex_integrations import SnowflakeCortexIntegrations
    from .snowflake_cortex_model import SnowflakeCortexModel
    from .snowflake_cortex_pat_token_auth import SnowflakeCortexPatTokenAuth
    from .snowflake_cortex_provider_account import SnowflakeCortexProviderAccount
    from .sort_direction import SortDirection
    from .spa_cy_framework import SpaCyFramework
    from .span_attribute_filter import SpanAttributeFilter
    from .span_attribute_filter_operator import SpanAttributeFilterOperator
    from .span_attribute_filter_value import SpanAttributeFilterValue
    from .span_field_filter import SpanFieldFilter
    from .span_field_filter_operator import SpanFieldFilterOperator
    from .span_field_filter_span_field_name import SpanFieldFilterSpanFieldName
    from .span_field_filter_value import SpanFieldFilterValue
    from .spark_build import SparkBuild
    from .spark_config import SparkConfig
    from .spark_driver_config import SparkDriverConfig
    from .spark_executor_config import SparkExecutorConfig
    from .spark_executor_config_instances import SparkExecutorConfigInstances
    from .spark_executor_dynamic_scaling import SparkExecutorDynamicScaling
    from .spark_executor_fixed_instances import SparkExecutorFixedInstances
    from .spark_image import SparkImage
    from .spark_image_build import SparkImageBuild
    from .spark_image_build_build_source import SparkImageBuildBuildSource
    from .spark_job import SparkJob
    from .spark_job_entrypoint import SparkJobEntrypoint
    from .spark_job_image import SparkJobImage
    from .spark_job_java_entrypoint import SparkJobJavaEntrypoint
    from .spark_job_python_entrypoint import SparkJobPythonEntrypoint
    from .spark_job_python_notebook_entrypoint import SparkJobPythonNotebookEntrypoint
    from .spark_job_scala_entrypoint import SparkJobScalaEntrypoint
    from .spark_job_scala_notebook_entrypoint import SparkJobScalaNotebookEntrypoint
    from .spark_job_trigger_input import SparkJobTriggerInput
    from .sqs_input_config import SqsInputConfig
    from .sqs_output_config import SqsOutputConfig
    from .sqs_queue_metric_config import SqsQueueMetricConfig
    from .sqs_queue_metric_config_auth import SqsQueueMetricConfigAuth
    from .ssh_server import SshServer
    from .ssh_server_config import SshServerConfig
    from .sso_team_manifest import SsoTeamManifest
    from .stage_artifact_response import StageArtifactResponse
    from .static_volume_config import StaticVolumeConfig
    from .stats_models_framework import StatsModelsFramework
    from .string_data_mount import StringDataMount
    from .subject import Subject
    from .subject_type import SubjectType
    from .sync_token_in_secret_store_info import SyncTokenInSecretStoreInfo
    from .sync_virtual_account_token_response import SyncVirtualAccountTokenResponse
    from .system_message import SystemMessage
    from .system_message_content import SystemMessageContent
    from .task_docker_file_build import TaskDockerFileBuild
    from .task_py_spark_build import TaskPySparkBuild
    from .task_python_build import TaskPythonBuild
    from .team import Team
    from .team_manifest import TeamManifest
    from .team_owned_by import TeamOwnedBy
    from .tensor_flow_framework import TensorFlowFramework
    from .terminate_job_response import TerminateJobResponse
    from .text_content_part import TextContentPart
    from .text_content_part_text import TextContentPartText
    from .together_ai_integrations import TogetherAiIntegrations
    from .together_ai_key_auth import TogetherAiKeyAuth
    from .together_ai_model import TogetherAiModel
    from .together_ai_provider_account import TogetherAiProviderAccount
    from .token_pagination import TokenPagination
    from .tool_call import ToolCall
    from .tool_message import ToolMessage
    from .tool_message_content import ToolMessageContent
    from .tool_schema import ToolSchema
    from .trace_span import TraceSpan
    from .tracing_project import TracingProject
    from .tracing_project_manifest import TracingProjectManifest
    from .transformers_framework import TransformersFramework
    from .trigger_job_run_response import TriggerJobRunResponse
    from .true_foundry_apply_request_manifest import TrueFoundryApplyRequestManifest
    from .true_foundry_apply_response import TrueFoundryApplyResponse
    from .true_foundry_apply_response_action import TrueFoundryApplyResponseAction
    from .true_foundry_apply_response_existing_manifest import TrueFoundryApplyResponseExistingManifest
    from .true_foundry_artifact_source import TrueFoundryArtifactSource
    from .true_foundry_dbssm import TrueFoundryDbssm
    from .true_foundry_delete_request_manifest import TrueFoundryDeleteRequestManifest
    from .true_foundry_integrations import TrueFoundryIntegrations
    from .true_foundry_interactive_login import TrueFoundryInteractiveLogin
    from .true_foundry_managed_source import TrueFoundryManagedSource
    from .true_foundry_provider_account import TrueFoundryProviderAccount
    from .ttl_integrations import TtlIntegrations
    from .ttl_provider_account import TtlProviderAccount
    from .ttl_registry import TtlRegistry
    from .update_secret_input import UpdateSecretInput
    from .update_user_roles_response import UpdateUserRolesResponse
    from .upgrade_data import UpgradeData
    from .usage_code_snippet import UsageCodeSnippet
    from .user import User
    from .user_message import UserMessage
    from .user_message_content import UserMessageContent
    from .user_message_content_one_item import UserMessageContentOneItem
    from .user_metadata import UserMetadata
    from .user_metadata_tenant_role_managed_by import UserMetadataTenantRoleManagedBy
    from .user_resource import UserResource
    from .user_role_with_resource import UserRoleWithResource
    from .user_role_with_resource_resource_type import UserRoleWithResourceResourceType
    from .uv import Uv
    from .validation_error import ValidationError
    from .validation_error_loc_item import ValidationErrorLocItem
    from .vertex_model import VertexModel
    from .virtual_account import VirtualAccount
    from .virtual_account_manifest import VirtualAccountManifest
    from .virtual_account_owned_by import VirtualAccountOwnedBy
    from .virtual_mcp_server_integration import VirtualMcpServerIntegration
    from .virtual_mcp_server_source import VirtualMcpServerSource
    from .virtual_model import VirtualModel
    from .virtual_model_provider_account import VirtualModelProviderAccount
    from .volume import Volume
    from .volume_browser import VolumeBrowser
    from .volume_config import VolumeConfig
    from .volume_mount import VolumeMount
    from .webhook_basic_auth import WebhookBasicAuth
    from .webhook_bearer_auth import WebhookBearerAuth
    from .webhook_integration import WebhookIntegration
    from .webhook_integration_auth_data import WebhookIntegrationAuthData
    from .webhook_integrations import WebhookIntegrations
    from .webhook_provider_account import WebhookProviderAccount
    from .weight_based_load_balancing import WeightBasedLoadBalancing
    from .weight_based_load_balancing_rule import WeightBasedLoadBalancingRule
    from .workbench_image import WorkbenchImage
    from .worker_config import WorkerConfig
    from .worker_config_input_config import WorkerConfigInputConfig
    from .worker_config_output_config import WorkerConfigOutputConfig
    from .workflow import Workflow
    from .workflow_alert import WorkflowAlert
    from .workflow_flyte_entities_item import WorkflowFlyteEntitiesItem
    from .workflow_source import WorkflowSource
    from .workspace import Workspace
    from .workspace_manifest import WorkspaceManifest
    from .xg_boost_framework import XgBoostFramework
    from .xg_boost_model_schema import XgBoostModelSchema
    from .xg_boost_serialization_format import XgBoostSerializationFormat
_dynamic_imports: typing.Dict[str, str] = {
    "Account": ".account",
    "ActivateUserResponse": ".activate_user_response",
    "AddOnComponentSource": ".add_on_component_source",
    "AddonComponent": ".addon_component",
    "AddonComponentName": ".addon_component_name",
    "AddonComponentStatus": ".addon_component_status",
    "Ai21Integrations": ".ai21integrations",
    "Ai21KeyAuth": ".ai21key_auth",
    "Ai21Model": ".ai21model",
    "Ai21ProviderAccount": ".ai21provider_account",
    "AiFeaturesSettings": ".ai_features_settings",
    "Alert": ".alert",
    "AlertConfig": ".alert_config",
    "AlertConfigResource": ".alert_config_resource",
    "AlertConfigResourceType": ".alert_config_resource_type",
    "AlertSeverity": ".alert_severity",
    "AlertStatus": ".alert_status",
    "AmqpInputConfig": ".amqp_input_config",
    "AmqpMetricConfig": ".amqp_metric_config",
    "AmqpOutputConfig": ".amqp_output_config",
    "AnthropicIntegrations": ".anthropic_integrations",
    "AnthropicKeyAuth": ".anthropic_key_auth",
    "AnthropicModel": ".anthropic_model",
    "AnthropicProviderAccount": ".anthropic_provider_account",
    "Application": ".application",
    "ApplicationDebugInfo": ".application_debug_info",
    "ApplicationLifecycleStage": ".application_lifecycle_stage",
    "ApplicationMetadata": ".application_metadata",
    "ApplicationProblem": ".application_problem",
    "ApplicationSet": ".application_set",
    "ApplicationSetComponentsItem": ".application_set_components_item",
    "ApplicationType": ".application_type",
    "ApplyMlEntityResponse": ".apply_ml_entity_response",
    "ApplyMlEntityResponseData": ".apply_ml_entity_response_data",
    "Artifact": ".artifact",
    "ArtifactManifest": ".artifact_manifest",
    "ArtifactManifestSource": ".artifact_manifest_source",
    "ArtifactPath": ".artifact_path",
    "ArtifactType": ".artifact_type",
    "ArtifactVersion": ".artifact_version",
    "ArtifactsCacheVolume": ".artifacts_cache_volume",
    "ArtifactsDownload": ".artifacts_download",
    "ArtifactsDownloadArtifactsItem": ".artifacts_download_artifacts_item",
    "AssistantMessage": ".assistant_message",
    "AssistantMessageContent": ".assistant_message_content",
    "AssistantMessageContentOneItem": ".assistant_message_content_one_item",
    "AsyncProcessorSidecar": ".async_processor_sidecar",
    "AsyncService": ".async_service",
    "AsyncServiceAutoscaling": ".async_service_autoscaling",
    "AsyncServiceAutoscalingMetrics": ".async_service_autoscaling_metrics",
    "AsyncServiceReplicas": ".async_service_replicas",
    "AutoRotate": ".auto_rotate",
    "Autoshutdown": ".autoshutdown",
    "AwsAccessKeyAuth": ".aws_access_key_auth",
    "AwsAccessKeyBasedAuth": ".aws_access_key_based_auth",
    "AwsAssumedRoleBasedAuth": ".aws_assumed_role_based_auth",
    "AwsBedrockAssumedRoleBasedAuth": ".aws_bedrock_assumed_role_based_auth",
    "AwsBedrockGuardrailConfig": ".aws_bedrock_guardrail_config",
    "AwsBedrockGuardrailConfigAuthData": ".aws_bedrock_guardrail_config_auth_data",
    "AwsBedrockGuardrailConfigOperation": ".aws_bedrock_guardrail_config_operation",
    "AwsBedrockProviderAccount": ".aws_bedrock_provider_account",
    "AwsBedrockProviderAccountAuthData": ".aws_bedrock_provider_account_auth_data",
    "AwsEcr": ".aws_ecr",
    "AwsEcrAuthData": ".aws_ecr_auth_data",
    "AwsEksIntegration": ".aws_eks_integration",
    "AwsEksIntegrationAuthData": ".aws_eks_integration_auth_data",
    "AwsInferentia": ".aws_inferentia",
    "AwsIntegrations": ".aws_integrations",
    "AwsParameterStore": ".aws_parameter_store",
    "AwsParameterStoreAuthData": ".aws_parameter_store_auth_data",
    "AwsProviderAccount": ".aws_provider_account",
    "AwsProviderAccountAuthData": ".aws_provider_account_auth_data",
    "AwsRegion": ".aws_region",
    "AwsS3": ".aws_s3",
    "AwsS3AuthData": ".aws_s3auth_data",
    "AwsSagemakerProviderAccount": ".aws_sagemaker_provider_account",
    "AwsSagemakerProviderAccountAuthData": ".aws_sagemaker_provider_account_auth_data",
    "AwsSecretsManager": ".aws_secrets_manager",
    "AwsSecretsManagerAuthData": ".aws_secrets_manager_auth_data",
    "AwsSqsAccessKeyBasedAuth": ".aws_sqs_access_key_based_auth",
    "AwsSqsAssumedRoleBasedAuth": ".aws_sqs_assumed_role_based_auth",
    "AzureAksIntegration": ".azure_aks_integration",
    "AzureBasicAuth": ".azure_basic_auth",
    "AzureBlobStorage": ".azure_blob_storage",
    "AzureConnectionStringAuth": ".azure_connection_string_auth",
    "AzureContainerRegistry": ".azure_container_registry",
    "AzureContentSafetyCategory": ".azure_content_safety_category",
    "AzureContentSafetyGuardrailConfig": ".azure_content_safety_guardrail_config",
    "AzureFoundryModel": ".azure_foundry_model",
    "AzureFoundryProviderAccount": ".azure_foundry_provider_account",
    "AzureIntegrations": ".azure_integrations",
    "AzureKeyAuth": ".azure_key_auth",
    "AzureOAuth": ".azure_o_auth",
    "AzureOpenAiModel": ".azure_open_ai_model",
    "AzureOpenAiProviderAccount": ".azure_open_ai_provider_account",
    "AzurePiiCategory": ".azure_pii_category",
    "AzurePiiGuardrailConfig": ".azure_pii_guardrail_config",
    "AzurePiiGuardrailConfigDomain": ".azure_pii_guardrail_config_domain",
    "AzureProviderAccount": ".azure_provider_account",
    "AzureReposIntegration": ".azure_repos_integration",
    "AzureVault": ".azure_vault",
    "BaseArtifactVersion": ".base_artifact_version",
    "BaseArtifactVersionManifest": ".base_artifact_version_manifest",
    "BaseAutoscaling": ".base_autoscaling",
    "BaseOAuth2Login": ".base_o_auth2login",
    "BaseOAuth2LoginJwtSource": ".base_o_auth2login_jwt_source",
    "BaseService": ".base_service",
    "BaseServiceImage": ".base_service_image",
    "BaseServiceMountsItem": ".base_service_mounts_item",
    "BaseWorkbenchInput": ".base_workbench_input",
    "BaseWorkbenchInputMountsItem": ".base_workbench_input_mounts_item",
    "BasicAuthCreds": ".basic_auth_creds",
    "BedrockModel": ".bedrock_model",
    "BitbucketIntegration": ".bitbucket_integration",
    "BitbucketProviderAccount": ".bitbucket_provider_account",
    "BlobStorageReference": ".blob_storage_reference",
    "BlueGreen": ".blue_green",
    "BudgetAlert": ".budget_alert",
    "BudgetConfig": ".budget_config",
    "BudgetLimitUnit": ".budget_limit_unit",
    "BudgetRule": ".budget_rule",
    "BudgetWhen": ".budget_when",
    "Build": ".build",
    "BuildBuildSource": ".build_build_source",
    "BuildBuildSpec": ".build_build_spec",
    "BuildInfo": ".build_info",
    "BuildStatus": ".build_status",
    "Canary": ".canary",
    "CanaryStep": ".canary_step",
    "CerebrasIntegrations": ".cerebras_integrations",
    "CerebrasKeyAuth": ".cerebras_key_auth",
    "CerebrasModel": ".cerebras_model",
    "CerebrasProviderAccount": ".cerebras_provider_account",
    "ChangePasswordResponse": ".change_password_response",
    "ChatPromptManifest": ".chat_prompt_manifest",
    "ChatPromptManifestMcpServersItem": ".chat_prompt_manifest_mcp_servers_item",
    "ChatPromptManifestMessagesItem": ".chat_prompt_manifest_messages_item",
    "ChatPromptManifestResponseFormat": ".chat_prompt_manifest_response_format",
    "ChatPromptManifestRoutingConfig": ".chat_prompt_manifest_routing_config",
    "ClouderaIntegrations": ".cloudera_integrations",
    "ClouderaModel": ".cloudera_model",
    "ClouderaProviderAccount": ".cloudera_provider_account",
    "ClouderaProviderAccountAuthData": ".cloudera_provider_account_auth_data",
    "ClouderaTokenAuth": ".cloudera_token_auth",
    "ClouderaWorkloadAuthToken": ".cloudera_workload_auth_token",
    "Cluster": ".cluster",
    "ClusterGateway": ".cluster_gateway",
    "ClusterManifest": ".cluster_manifest",
    "ClusterManifestClusterType": ".cluster_manifest_cluster_type",
    "ClusterManifestMonitoring": ".cluster_manifest_monitoring",
    "ClusterManifestNodeLabelKeys": ".cluster_manifest_node_label_keys",
    "ClusterManifestWorkbenchConfig": ".cluster_manifest_workbench_config",
    "ClusterType": ".cluster_type",
    "Codeserver": ".codeserver",
    "CohereIntegrations": ".cohere_integrations",
    "CohereKeyAuth": ".cohere_key_auth",
    "CohereModel": ".cohere_model",
    "CohereProviderAccount": ".cohere_provider_account",
    "Collaborator": ".collaborator",
    "CommonToolsSettings": ".common_tools_settings",
    "Config": ".config",
    "ContainerTaskConfig": ".container_task_config",
    "ContainerTaskConfigImage": ".container_task_config_image",
    "ContainerTaskConfigMountsItem": ".container_task_config_mounts_item",
    "CoreNatsOutputConfig": ".core_nats_output_config",
    "CpuUtilizationMetric": ".cpu_utilization_metric",
    "CreateMultiPartUploadRequest": ".create_multi_part_upload_request",
    "CreatePersonalAccessTokenResponse": ".create_personal_access_token_response",
    "CronMetric": ".cron_metric",
    "CustomBasicAuth": ".custom_basic_auth",
    "CustomBearerAuth": ".custom_bearer_auth",
    "CustomBlobStorage": ".custom_blob_storage",
    "CustomGuardrailConfig": ".custom_guardrail_config",
    "CustomGuardrailConfigAuthData": ".custom_guardrail_config_auth_data",
    "CustomGuardrailConfigOperation": ".custom_guardrail_config_operation",
    "CustomGuardrailConfigTarget": ".custom_guardrail_config_target",
    "CustomHelmRepo": ".custom_helm_repo",
    "CustomIntegrations": ".custom_integrations",
    "CustomJwtAuthIntegration": ".custom_jwt_auth_integration",
    "CustomProviderAccount": ".custom_provider_account",
    "CustomTlsSettings": ".custom_tls_settings",
    "CustomUsernamePasswordArtifactsRegistry": ".custom_username_password_artifacts_registry",
    "DataDirectory": ".data_directory",
    "DataDirectoryManifest": ".data_directory_manifest",
    "DataDirectoryManifestSource": ".data_directory_manifest_source",
    "DatabricksApiKeyAuth": ".databricks_api_key_auth",
    "DatabricksIntegrations": ".databricks_integrations",
    "DatabricksModel": ".databricks_model",
    "DatabricksProviderAccount": ".databricks_provider_account",
    "DatabricksProviderAccountAuthData": ".databricks_provider_account_auth_data",
    "DatabricksServicePrincipalAuth": ".databricks_service_principal_auth",
    "DeactivateUserResponse": ".deactivate_user_response",
    "DeepinfraIntegrations": ".deepinfra_integrations",
    "DeepinfraKeyAuth": ".deepinfra_key_auth",
    "DeepinfraModel": ".deepinfra_model",
    "DeepinfraProviderAccount": ".deepinfra_provider_account",
    "DeleteApplicationResponse": ".delete_application_response",
    "DeleteJobRunResponse": ".delete_job_run_response",
    "DeletePersonalAccessTokenResponse": ".delete_personal_access_token_response",
    "DeleteSecretGroupResponse": ".delete_secret_group_response",
    "DeleteTeamResponse": ".delete_team_response",
    "DeleteUserResponse": ".delete_user_response",
    "DeleteVirtualAccountResponse": ".delete_virtual_account_response",
    "Deployment": ".deployment",
    "DeploymentBuild": ".deployment_build",
    "DeploymentManifest": ".deployment_manifest",
    "DeploymentStatus": ".deployment_status",
    "DeploymentStatusValue": ".deployment_status_value",
    "DeploymentTransition": ".deployment_transition",
    "DeveloperMessage": ".developer_message",
    "DeveloperMessageContent": ".developer_message_content",
    "DockerFileBuild": ".docker_file_build",
    "DockerFileBuildCommand": ".docker_file_build_command",
    "DockerhubBasicAuth": ".dockerhub_basic_auth",
    "DockerhubIntegrations": ".dockerhub_integrations",
    "DockerhubProviderAccount": ".dockerhub_provider_account",
    "DockerhubRegistry": ".dockerhub_registry",
    "DynamicVolumeConfig": ".dynamic_volume_config",
    "Email": ".email",
    "EmailNotificationChannel": ".email_notification_channel",
    "EmptyResponse": ".empty_response",
    "Endpoint": ".endpoint",
    "EnkryptAiGuardrailConfig": ".enkrypt_ai_guardrail_config",
    "EnkryptAiGuardrailConfigOperation": ".enkrypt_ai_guardrail_config_operation",
    "EnkryptAiKeyAuth": ".enkrypt_ai_key_auth",
    "Environment": ".environment",
    "EnvironmentColor": ".environment_color",
    "EnvironmentManifest": ".environment_manifest",
    "EnvironmentOptimizeFor": ".environment_optimize_for",
    "Event": ".event",
    "EventChart": ".event_chart",
    "EventChartCategory": ".event_chart_category",
    "EventInvolvedObject": ".event_involved_object",
    "ExternalBlobStorageSource": ".external_blob_storage_source",
    "FastAiFramework": ".fast_ai_framework",
    "FiddlerGuardType": ".fiddler_guard_type",
    "FiddlerGuardrailConfig": ".fiddler_guardrail_config",
    "FiddlerKeyAuth": ".fiddler_key_auth",
    "FileInfo": ".file_info",
    "FlyteLaunchPlan": ".flyte_launch_plan",
    "FlyteLaunchPlanId": ".flyte_launch_plan_id",
    "FlyteLaunchPlanSpec": ".flyte_launch_plan_spec",
    "FlyteTask": ".flyte_task",
    "FlyteTaskCustom": ".flyte_task_custom",
    "FlyteTaskCustomTruefoundry": ".flyte_task_custom_truefoundry",
    "FlyteTaskId": ".flyte_task_id",
    "FlyteTaskTemplate": ".flyte_task_template",
    "FlyteWorkflow": ".flyte_workflow",
    "FlyteWorkflowId": ".flyte_workflow_id",
    "FlyteWorkflowTemplate": ".flyte_workflow_template",
    "ForwardAction": ".forward_action",
    "Function": ".function",
    "FunctionSchema": ".function_schema",
    "GatewayConfig": ".gateway_config",
    "GatewayConfiguration": ".gateway_configuration",
    "GatewayOtelConfig": ".gateway_otel_config",
    "GatewayOtelConfigOtelTracesExporterConfig": ".gateway_otel_config_otel_traces_exporter_config",
    "GatewayRequestMetadataFilter": ".gateway_request_metadata_filter",
    "GatewayRequestMetadataFilterOperator": ".gateway_request_metadata_filter_operator",
    "GatewayRequestMetadataFilterValue": ".gateway_request_metadata_filter_value",
    "GcpApiKeyAuth": ".gcp_api_key_auth",
    "GcpGcr": ".gcp_gcr",
    "GcpGcs": ".gcp_gcs",
    "GcpGkeIntegration": ".gcp_gke_integration",
    "GcpGsm": ".gcp_gsm",
    "GcpIntegrations": ".gcp_integrations",
    "GcpKeyFileAuth": ".gcp_key_file_auth",
    "GcpProviderAccount": ".gcp_provider_account",
    "GcpRegion": ".gcp_region",
    "GcpTpu": ".gcp_tpu",
    "GeminiModel": ".gemini_model",
    "GetAlertsResponse": ".get_alerts_response",
    "GetApplicationDeploymentResponse": ".get_application_deployment_response",
    "GetApplicationResponse": ".get_application_response",
    "GetArtifactResponse": ".get_artifact_response",
    "GetArtifactVersionResponse": ".get_artifact_version_response",
    "GetAuthenticatedVcsurlResponse": ".get_authenticated_vcsurl_response",
    "GetAutoProvisioningStateResponse": ".get_auto_provisioning_state_response",
    "GetChartsResponse": ".get_charts_response",
    "GetClusterResponse": ".get_cluster_response",
    "GetDataDirectoryResponse": ".get_data_directory_response",
    "GetEnvironmentResponse": ".get_environment_response",
    "GetEventsResponse": ".get_events_response",
    "GetJobRunResponse": ".get_job_run_response",
    "GetLogsResponse": ".get_logs_response",
    "GetMlRepoResponse": ".get_ml_repo_response",
    "GetModelResponse": ".get_model_response",
    "GetModelVersionResponse": ".get_model_version_response",
    "GetOrCreatePersonalAccessTokenResponse": ".get_or_create_personal_access_token_response",
    "GetPromptResponse": ".get_prompt_response",
    "GetPromptVersionResponse": ".get_prompt_version_response",
    "GetSecretGroupResponse": ".get_secret_group_response",
    "GetSecretResponse": ".get_secret_response",
    "GetSignedUrLsRequest": ".get_signed_ur_ls_request",
    "GetSignedUrLsResponse": ".get_signed_ur_ls_response",
    "GetSuggestedDeploymentEndpointResponse": ".get_suggested_deployment_endpoint_response",
    "GetTeamResponse": ".get_team_response",
    "GetTokenForVirtualAccountResponse": ".get_token_for_virtual_account_response",
    "GetUserResourcesResponse": ".get_user_resources_response",
    "GetUserResponse": ".get_user_response",
    "GetUserTeamsResponse": ".get_user_teams_response",
    "GetVirtualAccountResponse": ".get_virtual_account_response",
    "GetWorkspaceResponse": ".get_workspace_response",
    "GitHelmRepo": ".git_helm_repo",
    "GitRepositoryExistsResponse": ".git_repository_exists_response",
    "GitSource": ".git_source",
    "GithubIntegration": ".github_integration",
    "GithubProviderAccount": ".github_provider_account",
    "GitlabIntegration": ".gitlab_integration",
    "GitlabProviderAccount": ".gitlab_provider_account",
    "GluonFramework": ".gluon_framework",
    "GoogleGeminiProviderAccount": ".google_gemini_provider_account",
    "GoogleVertexProviderAccount": ".google_vertex_provider_account",
    "Graph": ".graph",
    "GraphChartType": ".graph_chart_type",
    "GroqIntegrations": ".groq_integrations",
    "GroqKeyAuth": ".groq_key_auth",
    "GroqModel": ".groq_model",
    "GroqProviderAccount": ".groq_provider_account",
    "GuardrailConfigGroup": ".guardrail_config_group",
    "GuardrailConfigIntegrations": ".guardrail_config_integrations",
    "Guardrails": ".guardrails",
    "GuardrailsConfig": ".guardrails_config",
    "GuardrailsRule": ".guardrails_rule",
    "GuardrailsWhen": ".guardrails_when",
    "H2OFramework": ".h2o_framework",
    "HashicorpIntegrations": ".hashicorp_integrations",
    "HashicorpProviderAccount": ".hashicorp_provider_account",
    "HashicorpTokenAuth": ".hashicorp_token_auth",
    "HashicorpVaultIntegration": ".hashicorp_vault_integration",
    "HeaderMatch": ".header_match",
    "HeaderRoutingConfig": ".header_routing_config",
    "HealthProbe": ".health_probe",
    "Helm": ".helm",
    "HelmRepo": ".helm_repo",
    "HelmSource": ".helm_source",
    "HttpError": ".http_error",
    "HttpErrorCode": ".http_error_code",
    "HttpProbe": ".http_probe",
    "HttpValidationError": ".http_validation_error",
    "HuggingfaceArtifactSource": ".huggingface_artifact_source",
    "IChange": ".i_change",
    "IChangeOperation": ".i_change_operation",
    "Image": ".image",
    "ImageCommand": ".image_command",
    "ImageContentPart": ".image_content_part",
    "ImageContentPartImageUrl": ".image_content_part_image_url",
    "ImageContentPartImageUrlUrl": ".image_content_part_image_url_url",
    "InferMethodName": ".infer_method_name",
    "InfraProviderAccount": ".infra_provider_account",
    "IngressControllerConfig": ".ingress_controller_config",
    "InputOutputBasedCostMetricValue": ".input_output_based_cost_metric_value",
    "Intercept": ".intercept",
    "InterceptRulesItem": ".intercept_rules_item",
    "InterceptRulesItemAction": ".intercept_rules_item_action",
    "InternalArtifactVersion": ".internal_artifact_version",
    "InternalListArtifactVersionsResponse": ".internal_list_artifact_versions_response",
    "InternalListArtifactVersionsResponseDataItem": ".internal_list_artifact_versions_response_data_item",
    "InternalModelVersion": ".internal_model_version",
    "InviteUserResponse": ".invite_user_response",
    "IsClusterConnectedResponse": ".is_cluster_connected_response",
    "JFrogIntegrations": ".j_frog_integrations",
    "JfrogArtifactsRegistry": ".jfrog_artifacts_registry",
    "JfrogBasicAuth": ".jfrog_basic_auth",
    "JfrogProviderAccount": ".jfrog_provider_account",
    "Job": ".job",
    "JobAlert": ".job_alert",
    "JobImage": ".job_image",
    "JobMountsItem": ".job_mounts_item",
    "JobRun": ".job_run",
    "JobRunStatus": ".job_run_status",
    "JobRunsSortBy": ".job_runs_sort_by",
    "JobTrigger": ".job_trigger",
    "JobTriggerInput": ".job_trigger_input",
    "JobTriggerInputCommand": ".job_trigger_input_command",
    "JsonObjectResponseFormat": ".json_object_response_format",
    "JsonSchema": ".json_schema",
    "JsonSchemaResponseFormat": ".json_schema_response_format",
    "Jwt": ".jwt",
    "JwtAuthConfig": ".jwt_auth_config",
    "JwtAuthConfigClaimsItem": ".jwt_auth_config_claims_item",
    "KafkaInputConfig": ".kafka_input_config",
    "KafkaMetricConfig": ".kafka_metric_config",
    "KafkaOutputConfig": ".kafka_output_config",
    "KafkaSaslAuth": ".kafka_sasl_auth",
    "KerasFramework": ".keras_framework",
    "Kustomize": ".kustomize",
    "LatencyBasedLoadBalanceTarget": ".latency_based_load_balance_target",
    "LatencyBasedLoadBalancing": ".latency_based_load_balancing",
    "LatencyBasedLoadBalancingRule": ".latency_based_load_balancing_rule",
    "LibraryName": ".library_name",
    "LightGbmFramework": ".light_gbm_framework",
    "ListApplicationDeploymentsResponse": ".list_application_deployments_response",
    "ListApplicationsResponse": ".list_applications_response",
    "ListArtifactVersionsResponse": ".list_artifact_versions_response",
    "ListArtifactsResponse": ".list_artifacts_response",
    "ListClusterAddonsResponse": ".list_cluster_addons_response",
    "ListClustersResponse": ".list_clusters_response",
    "ListDataDirectoriesResponse": ".list_data_directories_response",
    "ListEnvironmentsResponse": ".list_environments_response",
    "ListFilesRequest": ".list_files_request",
    "ListFilesResponse": ".list_files_response",
    "ListJobRunResponse": ".list_job_run_response",
    "ListMlReposResponse": ".list_ml_repos_response",
    "ListModelVersionsResponse": ".list_model_versions_response",
    "ListModelsResponse": ".list_models_response",
    "ListPersonalAccessTokenResponse": ".list_personal_access_token_response",
    "ListPromptVersionsResponse": ".list_prompt_versions_response",
    "ListPromptsResponse": ".list_prompts_response",
    "ListSecretGroupResponse": ".list_secret_group_response",
    "ListSecretsResponse": ".list_secrets_response",
    "ListTeamsResponse": ".list_teams_response",
    "ListUsersResponse": ".list_users_response",
    "ListVirtualAccountResponse": ".list_virtual_account_response",
    "ListWorkspacesResponse": ".list_workspaces_response",
    "LoadBalanceTarget": ".load_balance_target",
    "LoadBalancingConfig": ".load_balancing_config",
    "LoadBalancingRule": ".load_balancing_rule",
    "LoadBalancingWhen": ".load_balancing_when",
    "LocalArtifactSource": ".local_artifact_source",
    "LocalModelSource": ".local_model_source",
    "LocalSource": ".local_source",
    "Log": ".log",
    "LogsFilterQuery": ".logs_filter_query",
    "LogsFilterQueryType": ".logs_filter_query_type",
    "LogsResponse": ".logs_response",
    "LogsSearchFilterType": ".logs_search_filter_type",
    "LogsSearchOperatorType": ".logs_search_operator_type",
    "LogsSortingDirection": ".logs_sorting_direction",
    "Manual": ".manual",
    "McpServerAuth": ".mcp_server_auth",
    "McpServerHeaderAuth": ".mcp_server_header_auth",
    "McpServerHeaderOverrideAuth": ".mcp_server_header_override_auth",
    "McpServerIntegration": ".mcp_server_integration",
    "McpServerIntegrationTransport": ".mcp_server_integration_transport",
    "McpServerIntegrations": ".mcp_server_integrations",
    "McpServerOAuth2": ".mcp_server_o_auth2",
    "McpServerOAuth2JwtSource": ".mcp_server_o_auth2jwt_source",
    "McpServerPassthrough": ".mcp_server_passthrough",
    "McpServerProviderAccount": ".mcp_server_provider_account",
    "McpServerToolDetails": ".mcp_server_tool_details",
    "McpServerWithFqn": ".mcp_server_with_fqn",
    "McpServerWithUrl": ".mcp_server_with_url",
    "McpTool": ".mcp_tool",
    "Metadata": ".metadata",
    "Metric": ".metric",
    "MimeType": ".mime_type",
    "MirrorAction": ".mirror_action",
    "MistralAiIntegrations": ".mistral_ai_integrations",
    "MistralAiKeyAuth": ".mistral_ai_key_auth",
    "MistralAiModel": ".mistral_ai_model",
    "MistralAiProviderAccount": ".mistral_ai_provider_account",
    "MlRepo": ".ml_repo",
    "MlRepoManifest": ".ml_repo_manifest",
    "Model": ".model",
    "ModelConfiguration": ".model_configuration",
    "ModelCostMetric": ".model_cost_metric",
    "ModelManifest": ".model_manifest",
    "ModelManifestFramework": ".model_manifest_framework",
    "ModelManifestSource": ".model_manifest_source",
    "ModelProviderAccount": ".model_provider_account",
    "ModelType": ".model_type",
    "ModelVersion": ".model_version",
    "ModelVersionEnvironment": ".model_version_environment",
    "MultiPartUpload": ".multi_part_upload",
    "MultiPartUploadResponse": ".multi_part_upload_response",
    "MultiPartUploadStorageProvider": ".multi_part_upload_storage_provider",
    "NatsInputConfig": ".nats_input_config",
    "NatsMetricConfig": ".nats_metric_config",
    "NatsOutputConfig": ".nats_output_config",
    "NatsUserPasswordAuth": ".nats_user_password_auth",
    "NodeSelector": ".node_selector",
    "NodeSelectorCapacityType": ".node_selector_capacity_type",
    "Nodepool": ".nodepool",
    "NodepoolSelector": ".nodepool_selector",
    "NomicIntegrations": ".nomic_integrations",
    "NomicKeyAuth": ".nomic_key_auth",
    "NomicModel": ".nomic_model",
    "NomicProviderAccount": ".nomic_provider_account",
    "NonNegativeFloat": ".non_negative_float",
    "Notebook": ".notebook",
    "NotebookConfig": ".notebook_config",
    "NotificationTarget": ".notification_target",
    "NotificationTargetForAlertRule": ".notification_target_for_alert_rule",
    "NvidiaGpu": ".nvidia_gpu",
    "NvidiaMiggpu": ".nvidia_miggpu",
    "NvidiaMiggpuProfile": ".nvidia_miggpu_profile",
    "NvidiaTimeslicingGpu": ".nvidia_timeslicing_gpu",
    "OAuth2LoginProvider": ".o_auth2login_provider",
    "OciRepo": ".oci_repo",
    "OllamaIntegrations": ".ollama_integrations",
    "OllamaKeyAuth": ".ollama_key_auth",
    "OllamaModel": ".ollama_model",
    "OllamaProviderAccount": ".ollama_provider_account",
    "OnnxFramework": ".onnx_framework",
    "OpenAiIntegrations": ".open_ai_integrations",
    "OpenAiModel": ".open_ai_model",
    "OpenAiModerationsGuardrailConfig": ".open_ai_moderations_guardrail_config",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValue": ".open_ai_moderations_guardrail_config_category_thresholds_value",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment": ".open_ai_moderations_guardrail_config_category_thresholds_value_harassment",
    "OpenRouterApiKeyAuth": ".open_router_api_key_auth",
    "OpenRouterIntegrations": ".open_router_integrations",
    "OpenRouterModel": ".open_router_model",
    "OpenRouterProviderAccount": ".open_router_provider_account",
    "OpenaiApiKeyAuth": ".openai_api_key_auth",
    "OpenaiProviderAccount": ".openai_provider_account",
    "Operation": ".operation",
    "OtelExporterGrpcConfig": ".otel_exporter_grpc_config",
    "OtelExporterHttpConfig": ".otel_exporter_http_config",
    "OtelExporterHttpConfigEncoding": ".otel_exporter_http_config_encoding",
    "OwnedBy": ".owned_by",
    "PaddleFramework": ".paddle_framework",
    "PagerDuty": ".pager_duty",
    "PagerDutyIntegration": ".pager_duty_integration",
    "PagerDutyIntegrationKeyAuth": ".pager_duty_integration_key_auth",
    "PagerDutyIntegrations": ".pager_duty_integrations",
    "PagerDutyProviderAccount": ".pager_duty_provider_account",
    "Pagination": ".pagination",
    "PalmIntegrations": ".palm_integrations",
    "PalmKeyAuth": ".palm_key_auth",
    "PalmModel": ".palm_model",
    "PalmProviderAccount": ".palm_provider_account",
    "PaloAltoPrismaAirsGuardrailConfig": ".palo_alto_prisma_airs_guardrail_config",
    "PaloAltoPrismaAirsGuardrailConfigMode": ".palo_alto_prisma_airs_guardrail_config_mode",
    "PaloAltoPrismaAirsKeyAuth": ".palo_alto_prisma_airs_key_auth",
    "PangeaGuardType": ".pangea_guard_type",
    "PangeaGuardrailConfig": ".pangea_guardrail_config",
    "PangeaGuardrailConfigOperation": ".pangea_guardrail_config_operation",
    "PangeaKeyAuth": ".pangea_key_auth",
    "Param": ".param",
    "ParamParamType": ".param_param_type",
    "Parameters": ".parameters",
    "ParametersStop": ".parameters_stop",
    "PatronusAnswerRelevanceCriteria": ".patronus_answer_relevance_criteria",
    "PatronusAnswerRelevanceEvaluator": ".patronus_answer_relevance_evaluator",
    "PatronusEvaluator": ".patronus_evaluator",
    "PatronusGliderCriteria": ".patronus_glider_criteria",
    "PatronusGliderEvaluator": ".patronus_glider_evaluator",
    "PatronusGuardrailConfig": ".patronus_guardrail_config",
    "PatronusGuardrailConfigTarget": ".patronus_guardrail_config_target",
    "PatronusJudgeCriteria": ".patronus_judge_criteria",
    "PatronusJudgeEvaluator": ".patronus_judge_evaluator",
    "PatronusKeyAuth": ".patronus_key_auth",
    "PatronusPhiCriteria": ".patronus_phi_criteria",
    "PatronusPhiEvaluator": ".patronus_phi_evaluator",
    "PatronusPiiCriteria": ".patronus_pii_criteria",
    "PatronusPiiEvaluator": ".patronus_pii_evaluator",
    "PatronusToxicityCriteria": ".patronus_toxicity_criteria",
    "PatronusToxicityEvaluator": ".patronus_toxicity_evaluator",
    "PerThousandEmbeddingTokensCostMetric": ".per_thousand_embedding_tokens_cost_metric",
    "PerThousandTokensCostMetric": ".per_thousand_tokens_cost_metric",
    "Permissions": ".permissions",
    "PerplexityAiKeyAuth": ".perplexity_ai_key_auth",
    "PerplexityAiModel": ".perplexity_ai_model",
    "PerplexityAiProviderAccount": ".perplexity_ai_provider_account",
    "PerplexityIntegrations": ".perplexity_integrations",
    "PersonalAccessTokenManifest": ".personal_access_token_manifest",
    "Pip": ".pip",
    "Poetry": ".poetry",
    "PolicyActions": ".policy_actions",
    "PolicyEntityTypes": ".policy_entity_types",
    "PolicyFilters": ".policy_filters",
    "PolicyManifest": ".policy_manifest",
    "PolicyManifestMode": ".policy_manifest_mode",
    "PolicyManifestOperation": ".policy_manifest_operation",
    "PolicyMutationOperation": ".policy_mutation_operation",
    "PolicyValidationOperation": ".policy_validation_operation",
    "Port": ".port",
    "PortAppProtocol": ".port_app_protocol",
    "PortAuth": ".port_auth",
    "PortProtocol": ".port_protocol",
    "PresignedUrlObject": ".presigned_url_object",
    "PriorityBasedLoadBalanceTarget": ".priority_based_load_balance_target",
    "PriorityBasedLoadBalancing": ".priority_based_load_balancing",
    "PriorityBasedLoadBalancingRule": ".priority_based_load_balancing_rule",
    "PrometheusAlertRule": ".prometheus_alert_rule",
    "Prompt": ".prompt",
    "PromptFooGuardType": ".prompt_foo_guard_type",
    "PromptFooGuardrailConfig": ".prompt_foo_guardrail_config",
    "PromptFooGuardrailConfigOperation": ".prompt_foo_guardrail_config_operation",
    "PromptVersion": ".prompt_version",
    "ProviderAccounts": ".provider_accounts",
    "PublicCostMetric": ".public_cost_metric",
    "PySparkTaskConfig": ".py_spark_task_config",
    "PyTorchFramework": ".py_torch_framework",
    "PythonBuild": ".python_build",
    "PythonBuildCommand": ".python_build_command",
    "PythonBuildPythonDependencies": ".python_build_python_dependencies",
    "PythonTaskConfig": ".python_task_config",
    "PythonTaskConfigImage": ".python_task_config_image",
    "PythonTaskConfigMountsItem": ".python_task_config_mounts_item",
    "QuayArtifactsRegistry": ".quay_artifacts_registry",
    "QuayBasicAuth": ".quay_basic_auth",
    "QuayIntegrations": ".quay_integrations",
    "QuayProviderAccount": ".quay_provider_account",
    "QuerySpansResponse": ".query_spans_response",
    "RStudio": ".r_studio",
    "RateLimitConfig": ".rate_limit_config",
    "RateLimitRule": ".rate_limit_rule",
    "RateLimitUnit": ".rate_limit_unit",
    "RateLimitWhen": ".rate_limit_when",
    "Recommendation": ".recommendation",
    "RefusalContentPart": ".refusal_content_part",
    "RegisterUsersResponse": ".register_users_response",
    "RemoteSource": ".remote_source",
    "Resources": ".resources",
    "ResourcesDevicesItem": ".resources_devices_item",
    "ResourcesNode": ".resources_node",
    "RetryConfig": ".retry_config",
    "RevokeAllPersonalAccessTokenResponse": ".revoke_all_personal_access_token_response",
    "RoleManifest": ".role_manifest",
    "RolePermissions": ".role_permissions",
    "Rolling": ".rolling",
    "RpsMetric": ".rps_metric",
    "SagemakerModel": ".sagemaker_model",
    "SambaNovaIntegrations": ".samba_nova_integrations",
    "SambaNovaKeyAuth": ".samba_nova_key_auth",
    "SambaNovaModel": ".samba_nova_model",
    "SambaNovaProviderAccount": ".samba_nova_provider_account",
    "Schedule": ".schedule",
    "ScheduleConcurrencyPolicy": ".schedule_concurrency_policy",
    "Secret": ".secret",
    "SecretGroup": ".secret_group",
    "SecretGroupManifest": ".secret_group_manifest",
    "SecretInput": ".secret_input",
    "SecretMount": ".secret_mount",
    "SecretStoreConfig": ".secret_store_config",
    "SecretVersion": ".secret_version",
    "SelfHostedModel": ".self_hosted_model",
    "SelfHostedModelAuthData": ".self_hosted_model_auth_data",
    "SelfHostedModelIntegrations": ".self_hosted_model_integrations",
    "SelfHostedModelModelServer": ".self_hosted_model_model_server",
    "SelfHostedModelProviderAccount": ".self_hosted_model_provider_account",
    "Service": ".service",
    "ServiceAutoscaling": ".service_autoscaling",
    "ServiceAutoscalingMetrics": ".service_autoscaling_metrics",
    "ServiceReplicas": ".service_replicas",
    "ServiceRolloutStrategy": ".service_rollout_strategy",
    "Session": ".session",
    "SignedUrl": ".signed_url",
    "SklearnFramework": ".sklearn_framework",
    "SklearnModelSchema": ".sklearn_model_schema",
    "SklearnSerializationFormat": ".sklearn_serialization_format",
    "SlaCutoff": ".sla_cutoff",
    "SlackBot": ".slack_bot",
    "SlackBotAuth": ".slack_bot_auth",
    "SlackBotIntegration": ".slack_bot_integration",
    "SlackIntegrations": ".slack_integrations",
    "SlackProviderAccount": ".slack_provider_account",
    "SlackWebhook": ".slack_webhook",
    "SlackWebhookAuth": ".slack_webhook_auth",
    "SlackWebhookIntegration": ".slack_webhook_integration",
    "SmtpCredentials": ".smtp_credentials",
    "SnowflakeCortexIntegrations": ".snowflake_cortex_integrations",
    "SnowflakeCortexModel": ".snowflake_cortex_model",
    "SnowflakeCortexPatTokenAuth": ".snowflake_cortex_pat_token_auth",
    "SnowflakeCortexProviderAccount": ".snowflake_cortex_provider_account",
    "SortDirection": ".sort_direction",
    "SpaCyFramework": ".spa_cy_framework",
    "SpanAttributeFilter": ".span_attribute_filter",
    "SpanAttributeFilterOperator": ".span_attribute_filter_operator",
    "SpanAttributeFilterValue": ".span_attribute_filter_value",
    "SpanFieldFilter": ".span_field_filter",
    "SpanFieldFilterOperator": ".span_field_filter_operator",
    "SpanFieldFilterSpanFieldName": ".span_field_filter_span_field_name",
    "SpanFieldFilterValue": ".span_field_filter_value",
    "SparkBuild": ".spark_build",
    "SparkConfig": ".spark_config",
    "SparkDriverConfig": ".spark_driver_config",
    "SparkExecutorConfig": ".spark_executor_config",
    "SparkExecutorConfigInstances": ".spark_executor_config_instances",
    "SparkExecutorDynamicScaling": ".spark_executor_dynamic_scaling",
    "SparkExecutorFixedInstances": ".spark_executor_fixed_instances",
    "SparkImage": ".spark_image",
    "SparkImageBuild": ".spark_image_build",
    "SparkImageBuildBuildSource": ".spark_image_build_build_source",
    "SparkJob": ".spark_job",
    "SparkJobEntrypoint": ".spark_job_entrypoint",
    "SparkJobImage": ".spark_job_image",
    "SparkJobJavaEntrypoint": ".spark_job_java_entrypoint",
    "SparkJobPythonEntrypoint": ".spark_job_python_entrypoint",
    "SparkJobPythonNotebookEntrypoint": ".spark_job_python_notebook_entrypoint",
    "SparkJobScalaEntrypoint": ".spark_job_scala_entrypoint",
    "SparkJobScalaNotebookEntrypoint": ".spark_job_scala_notebook_entrypoint",
    "SparkJobTriggerInput": ".spark_job_trigger_input",
    "SqsInputConfig": ".sqs_input_config",
    "SqsOutputConfig": ".sqs_output_config",
    "SqsQueueMetricConfig": ".sqs_queue_metric_config",
    "SqsQueueMetricConfigAuth": ".sqs_queue_metric_config_auth",
    "SshServer": ".ssh_server",
    "SshServerConfig": ".ssh_server_config",
    "SsoTeamManifest": ".sso_team_manifest",
    "StageArtifactResponse": ".stage_artifact_response",
    "StaticVolumeConfig": ".static_volume_config",
    "StatsModelsFramework": ".stats_models_framework",
    "StringDataMount": ".string_data_mount",
    "Subject": ".subject",
    "SubjectType": ".subject_type",
    "SyncTokenInSecretStoreInfo": ".sync_token_in_secret_store_info",
    "SyncVirtualAccountTokenResponse": ".sync_virtual_account_token_response",
    "SystemMessage": ".system_message",
    "SystemMessageContent": ".system_message_content",
    "TaskDockerFileBuild": ".task_docker_file_build",
    "TaskPySparkBuild": ".task_py_spark_build",
    "TaskPythonBuild": ".task_python_build",
    "Team": ".team",
    "TeamManifest": ".team_manifest",
    "TeamOwnedBy": ".team_owned_by",
    "TensorFlowFramework": ".tensor_flow_framework",
    "TerminateJobResponse": ".terminate_job_response",
    "TextContentPart": ".text_content_part",
    "TextContentPartText": ".text_content_part_text",
    "TogetherAiIntegrations": ".together_ai_integrations",
    "TogetherAiKeyAuth": ".together_ai_key_auth",
    "TogetherAiModel": ".together_ai_model",
    "TogetherAiProviderAccount": ".together_ai_provider_account",
    "TokenPagination": ".token_pagination",
    "ToolCall": ".tool_call",
    "ToolMessage": ".tool_message",
    "ToolMessageContent": ".tool_message_content",
    "ToolSchema": ".tool_schema",
    "TraceSpan": ".trace_span",
    "TracingProject": ".tracing_project",
    "TracingProjectManifest": ".tracing_project_manifest",
    "TransformersFramework": ".transformers_framework",
    "TriggerJobRunResponse": ".trigger_job_run_response",
    "TrueFoundryApplyRequestManifest": ".true_foundry_apply_request_manifest",
    "TrueFoundryApplyResponse": ".true_foundry_apply_response",
    "TrueFoundryApplyResponseAction": ".true_foundry_apply_response_action",
    "TrueFoundryApplyResponseExistingManifest": ".true_foundry_apply_response_existing_manifest",
    "TrueFoundryArtifactSource": ".true_foundry_artifact_source",
    "TrueFoundryDbssm": ".true_foundry_dbssm",
    "TrueFoundryDeleteRequestManifest": ".true_foundry_delete_request_manifest",
    "TrueFoundryIntegrations": ".true_foundry_integrations",
    "TrueFoundryInteractiveLogin": ".true_foundry_interactive_login",
    "TrueFoundryManagedSource": ".true_foundry_managed_source",
    "TrueFoundryProviderAccount": ".true_foundry_provider_account",
    "TtlIntegrations": ".ttl_integrations",
    "TtlProviderAccount": ".ttl_provider_account",
    "TtlRegistry": ".ttl_registry",
    "UpdateSecretInput": ".update_secret_input",
    "UpdateUserRolesResponse": ".update_user_roles_response",
    "UpgradeData": ".upgrade_data",
    "UsageCodeSnippet": ".usage_code_snippet",
    "User": ".user",
    "UserMessage": ".user_message",
    "UserMessageContent": ".user_message_content",
    "UserMessageContentOneItem": ".user_message_content_one_item",
    "UserMetadata": ".user_metadata",
    "UserMetadataTenantRoleManagedBy": ".user_metadata_tenant_role_managed_by",
    "UserResource": ".user_resource",
    "UserRoleWithResource": ".user_role_with_resource",
    "UserRoleWithResourceResourceType": ".user_role_with_resource_resource_type",
    "Uv": ".uv",
    "ValidationError": ".validation_error",
    "ValidationErrorLocItem": ".validation_error_loc_item",
    "VertexModel": ".vertex_model",
    "VirtualAccount": ".virtual_account",
    "VirtualAccountManifest": ".virtual_account_manifest",
    "VirtualAccountOwnedBy": ".virtual_account_owned_by",
    "VirtualMcpServerIntegration": ".virtual_mcp_server_integration",
    "VirtualMcpServerSource": ".virtual_mcp_server_source",
    "VirtualModel": ".virtual_model",
    "VirtualModelProviderAccount": ".virtual_model_provider_account",
    "Volume": ".volume",
    "VolumeBrowser": ".volume_browser",
    "VolumeConfig": ".volume_config",
    "VolumeMount": ".volume_mount",
    "WebhookBasicAuth": ".webhook_basic_auth",
    "WebhookBearerAuth": ".webhook_bearer_auth",
    "WebhookIntegration": ".webhook_integration",
    "WebhookIntegrationAuthData": ".webhook_integration_auth_data",
    "WebhookIntegrations": ".webhook_integrations",
    "WebhookProviderAccount": ".webhook_provider_account",
    "WeightBasedLoadBalancing": ".weight_based_load_balancing",
    "WeightBasedLoadBalancingRule": ".weight_based_load_balancing_rule",
    "WorkbenchImage": ".workbench_image",
    "WorkerConfig": ".worker_config",
    "WorkerConfigInputConfig": ".worker_config_input_config",
    "WorkerConfigOutputConfig": ".worker_config_output_config",
    "Workflow": ".workflow",
    "WorkflowAlert": ".workflow_alert",
    "WorkflowFlyteEntitiesItem": ".workflow_flyte_entities_item",
    "WorkflowSource": ".workflow_source",
    "Workspace": ".workspace",
    "WorkspaceManifest": ".workspace_manifest",
    "XgBoostFramework": ".xg_boost_framework",
    "XgBoostModelSchema": ".xg_boost_model_schema",
    "XgBoostSerializationFormat": ".xg_boost_serialization_format",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Account",
    "ActivateUserResponse",
    "AddOnComponentSource",
    "AddonComponent",
    "AddonComponentName",
    "AddonComponentStatus",
    "Ai21Integrations",
    "Ai21KeyAuth",
    "Ai21Model",
    "Ai21ProviderAccount",
    "AiFeaturesSettings",
    "Alert",
    "AlertConfig",
    "AlertConfigResource",
    "AlertConfigResourceType",
    "AlertSeverity",
    "AlertStatus",
    "AmqpInputConfig",
    "AmqpMetricConfig",
    "AmqpOutputConfig",
    "AnthropicIntegrations",
    "AnthropicKeyAuth",
    "AnthropicModel",
    "AnthropicProviderAccount",
    "Application",
    "ApplicationDebugInfo",
    "ApplicationLifecycleStage",
    "ApplicationMetadata",
    "ApplicationProblem",
    "ApplicationSet",
    "ApplicationSetComponentsItem",
    "ApplicationType",
    "ApplyMlEntityResponse",
    "ApplyMlEntityResponseData",
    "Artifact",
    "ArtifactManifest",
    "ArtifactManifestSource",
    "ArtifactPath",
    "ArtifactType",
    "ArtifactVersion",
    "ArtifactsCacheVolume",
    "ArtifactsDownload",
    "ArtifactsDownloadArtifactsItem",
    "AssistantMessage",
    "AssistantMessageContent",
    "AssistantMessageContentOneItem",
    "AsyncProcessorSidecar",
    "AsyncService",
    "AsyncServiceAutoscaling",
    "AsyncServiceAutoscalingMetrics",
    "AsyncServiceReplicas",
    "AutoRotate",
    "Autoshutdown",
    "AwsAccessKeyAuth",
    "AwsAccessKeyBasedAuth",
    "AwsAssumedRoleBasedAuth",
    "AwsBedrockAssumedRoleBasedAuth",
    "AwsBedrockGuardrailConfig",
    "AwsBedrockGuardrailConfigAuthData",
    "AwsBedrockGuardrailConfigOperation",
    "AwsBedrockProviderAccount",
    "AwsBedrockProviderAccountAuthData",
    "AwsEcr",
    "AwsEcrAuthData",
    "AwsEksIntegration",
    "AwsEksIntegrationAuthData",
    "AwsInferentia",
    "AwsIntegrations",
    "AwsParameterStore",
    "AwsParameterStoreAuthData",
    "AwsProviderAccount",
    "AwsProviderAccountAuthData",
    "AwsRegion",
    "AwsS3",
    "AwsS3AuthData",
    "AwsSagemakerProviderAccount",
    "AwsSagemakerProviderAccountAuthData",
    "AwsSecretsManager",
    "AwsSecretsManagerAuthData",
    "AwsSqsAccessKeyBasedAuth",
    "AwsSqsAssumedRoleBasedAuth",
    "AzureAksIntegration",
    "AzureBasicAuth",
    "AzureBlobStorage",
    "AzureConnectionStringAuth",
    "AzureContainerRegistry",
    "AzureContentSafetyCategory",
    "AzureContentSafetyGuardrailConfig",
    "AzureFoundryModel",
    "AzureFoundryProviderAccount",
    "AzureIntegrations",
    "AzureKeyAuth",
    "AzureOAuth",
    "AzureOpenAiModel",
    "AzureOpenAiProviderAccount",
    "AzurePiiCategory",
    "AzurePiiGuardrailConfig",
    "AzurePiiGuardrailConfigDomain",
    "AzureProviderAccount",
    "AzureReposIntegration",
    "AzureVault",
    "BaseArtifactVersion",
    "BaseArtifactVersionManifest",
    "BaseAutoscaling",
    "BaseOAuth2Login",
    "BaseOAuth2LoginJwtSource",
    "BaseService",
    "BaseServiceImage",
    "BaseServiceMountsItem",
    "BaseWorkbenchInput",
    "BaseWorkbenchInputMountsItem",
    "BasicAuthCreds",
    "BedrockModel",
    "BitbucketIntegration",
    "BitbucketProviderAccount",
    "BlobStorageReference",
    "BlueGreen",
    "BudgetAlert",
    "BudgetConfig",
    "BudgetLimitUnit",
    "BudgetRule",
    "BudgetWhen",
    "Build",
    "BuildBuildSource",
    "BuildBuildSpec",
    "BuildInfo",
    "BuildStatus",
    "Canary",
    "CanaryStep",
    "CerebrasIntegrations",
    "CerebrasKeyAuth",
    "CerebrasModel",
    "CerebrasProviderAccount",
    "ChangePasswordResponse",
    "ChatPromptManifest",
    "ChatPromptManifestMcpServersItem",
    "ChatPromptManifestMessagesItem",
    "ChatPromptManifestResponseFormat",
    "ChatPromptManifestRoutingConfig",
    "ClouderaIntegrations",
    "ClouderaModel",
    "ClouderaProviderAccount",
    "ClouderaProviderAccountAuthData",
    "ClouderaTokenAuth",
    "ClouderaWorkloadAuthToken",
    "Cluster",
    "ClusterGateway",
    "ClusterManifest",
    "ClusterManifestClusterType",
    "ClusterManifestMonitoring",
    "ClusterManifestNodeLabelKeys",
    "ClusterManifestWorkbenchConfig",
    "ClusterType",
    "Codeserver",
    "CohereIntegrations",
    "CohereKeyAuth",
    "CohereModel",
    "CohereProviderAccount",
    "Collaborator",
    "CommonToolsSettings",
    "Config",
    "ContainerTaskConfig",
    "ContainerTaskConfigImage",
    "ContainerTaskConfigMountsItem",
    "CoreNatsOutputConfig",
    "CpuUtilizationMetric",
    "CreateMultiPartUploadRequest",
    "CreatePersonalAccessTokenResponse",
    "CronMetric",
    "CustomBasicAuth",
    "CustomBearerAuth",
    "CustomBlobStorage",
    "CustomGuardrailConfig",
    "CustomGuardrailConfigAuthData",
    "CustomGuardrailConfigOperation",
    "CustomGuardrailConfigTarget",
    "CustomHelmRepo",
    "CustomIntegrations",
    "CustomJwtAuthIntegration",
    "CustomProviderAccount",
    "CustomTlsSettings",
    "CustomUsernamePasswordArtifactsRegistry",
    "DataDirectory",
    "DataDirectoryManifest",
    "DataDirectoryManifestSource",
    "DatabricksApiKeyAuth",
    "DatabricksIntegrations",
    "DatabricksModel",
    "DatabricksProviderAccount",
    "DatabricksProviderAccountAuthData",
    "DatabricksServicePrincipalAuth",
    "DeactivateUserResponse",
    "DeepinfraIntegrations",
    "DeepinfraKeyAuth",
    "DeepinfraModel",
    "DeepinfraProviderAccount",
    "DeleteApplicationResponse",
    "DeleteJobRunResponse",
    "DeletePersonalAccessTokenResponse",
    "DeleteSecretGroupResponse",
    "DeleteTeamResponse",
    "DeleteUserResponse",
    "DeleteVirtualAccountResponse",
    "Deployment",
    "DeploymentBuild",
    "DeploymentManifest",
    "DeploymentStatus",
    "DeploymentStatusValue",
    "DeploymentTransition",
    "DeveloperMessage",
    "DeveloperMessageContent",
    "DockerFileBuild",
    "DockerFileBuildCommand",
    "DockerhubBasicAuth",
    "DockerhubIntegrations",
    "DockerhubProviderAccount",
    "DockerhubRegistry",
    "DynamicVolumeConfig",
    "Email",
    "EmailNotificationChannel",
    "EmptyResponse",
    "Endpoint",
    "EnkryptAiGuardrailConfig",
    "EnkryptAiGuardrailConfigOperation",
    "EnkryptAiKeyAuth",
    "Environment",
    "EnvironmentColor",
    "EnvironmentManifest",
    "EnvironmentOptimizeFor",
    "Event",
    "EventChart",
    "EventChartCategory",
    "EventInvolvedObject",
    "ExternalBlobStorageSource",
    "FastAiFramework",
    "FiddlerGuardType",
    "FiddlerGuardrailConfig",
    "FiddlerKeyAuth",
    "FileInfo",
    "FlyteLaunchPlan",
    "FlyteLaunchPlanId",
    "FlyteLaunchPlanSpec",
    "FlyteTask",
    "FlyteTaskCustom",
    "FlyteTaskCustomTruefoundry",
    "FlyteTaskId",
    "FlyteTaskTemplate",
    "FlyteWorkflow",
    "FlyteWorkflowId",
    "FlyteWorkflowTemplate",
    "ForwardAction",
    "Function",
    "FunctionSchema",
    "GatewayConfig",
    "GatewayConfiguration",
    "GatewayOtelConfig",
    "GatewayOtelConfigOtelTracesExporterConfig",
    "GatewayRequestMetadataFilter",
    "GatewayRequestMetadataFilterOperator",
    "GatewayRequestMetadataFilterValue",
    "GcpApiKeyAuth",
    "GcpGcr",
    "GcpGcs",
    "GcpGkeIntegration",
    "GcpGsm",
    "GcpIntegrations",
    "GcpKeyFileAuth",
    "GcpProviderAccount",
    "GcpRegion",
    "GcpTpu",
    "GeminiModel",
    "GetAlertsResponse",
    "GetApplicationDeploymentResponse",
    "GetApplicationResponse",
    "GetArtifactResponse",
    "GetArtifactVersionResponse",
    "GetAuthenticatedVcsurlResponse",
    "GetAutoProvisioningStateResponse",
    "GetChartsResponse",
    "GetClusterResponse",
    "GetDataDirectoryResponse",
    "GetEnvironmentResponse",
    "GetEventsResponse",
    "GetJobRunResponse",
    "GetLogsResponse",
    "GetMlRepoResponse",
    "GetModelResponse",
    "GetModelVersionResponse",
    "GetOrCreatePersonalAccessTokenResponse",
    "GetPromptResponse",
    "GetPromptVersionResponse",
    "GetSecretGroupResponse",
    "GetSecretResponse",
    "GetSignedUrLsRequest",
    "GetSignedUrLsResponse",
    "GetSuggestedDeploymentEndpointResponse",
    "GetTeamResponse",
    "GetTokenForVirtualAccountResponse",
    "GetUserResourcesResponse",
    "GetUserResponse",
    "GetUserTeamsResponse",
    "GetVirtualAccountResponse",
    "GetWorkspaceResponse",
    "GitHelmRepo",
    "GitRepositoryExistsResponse",
    "GitSource",
    "GithubIntegration",
    "GithubProviderAccount",
    "GitlabIntegration",
    "GitlabProviderAccount",
    "GluonFramework",
    "GoogleGeminiProviderAccount",
    "GoogleVertexProviderAccount",
    "Graph",
    "GraphChartType",
    "GroqIntegrations",
    "GroqKeyAuth",
    "GroqModel",
    "GroqProviderAccount",
    "GuardrailConfigGroup",
    "GuardrailConfigIntegrations",
    "Guardrails",
    "GuardrailsConfig",
    "GuardrailsRule",
    "GuardrailsWhen",
    "H2OFramework",
    "HashicorpIntegrations",
    "HashicorpProviderAccount",
    "HashicorpTokenAuth",
    "HashicorpVaultIntegration",
    "HeaderMatch",
    "HeaderRoutingConfig",
    "HealthProbe",
    "Helm",
    "HelmRepo",
    "HelmSource",
    "HttpError",
    "HttpErrorCode",
    "HttpProbe",
    "HttpValidationError",
    "HuggingfaceArtifactSource",
    "IChange",
    "IChangeOperation",
    "Image",
    "ImageCommand",
    "ImageContentPart",
    "ImageContentPartImageUrl",
    "ImageContentPartImageUrlUrl",
    "InferMethodName",
    "InfraProviderAccount",
    "IngressControllerConfig",
    "InputOutputBasedCostMetricValue",
    "Intercept",
    "InterceptRulesItem",
    "InterceptRulesItemAction",
    "InternalArtifactVersion",
    "InternalListArtifactVersionsResponse",
    "InternalListArtifactVersionsResponseDataItem",
    "InternalModelVersion",
    "InviteUserResponse",
    "IsClusterConnectedResponse",
    "JFrogIntegrations",
    "JfrogArtifactsRegistry",
    "JfrogBasicAuth",
    "JfrogProviderAccount",
    "Job",
    "JobAlert",
    "JobImage",
    "JobMountsItem",
    "JobRun",
    "JobRunStatus",
    "JobRunsSortBy",
    "JobTrigger",
    "JobTriggerInput",
    "JobTriggerInputCommand",
    "JsonObjectResponseFormat",
    "JsonSchema",
    "JsonSchemaResponseFormat",
    "Jwt",
    "JwtAuthConfig",
    "JwtAuthConfigClaimsItem",
    "KafkaInputConfig",
    "KafkaMetricConfig",
    "KafkaOutputConfig",
    "KafkaSaslAuth",
    "KerasFramework",
    "Kustomize",
    "LatencyBasedLoadBalanceTarget",
    "LatencyBasedLoadBalancing",
    "LatencyBasedLoadBalancingRule",
    "LibraryName",
    "LightGbmFramework",
    "ListApplicationDeploymentsResponse",
    "ListApplicationsResponse",
    "ListArtifactVersionsResponse",
    "ListArtifactsResponse",
    "ListClusterAddonsResponse",
    "ListClustersResponse",
    "ListDataDirectoriesResponse",
    "ListEnvironmentsResponse",
    "ListFilesRequest",
    "ListFilesResponse",
    "ListJobRunResponse",
    "ListMlReposResponse",
    "ListModelVersionsResponse",
    "ListModelsResponse",
    "ListPersonalAccessTokenResponse",
    "ListPromptVersionsResponse",
    "ListPromptsResponse",
    "ListSecretGroupResponse",
    "ListSecretsResponse",
    "ListTeamsResponse",
    "ListUsersResponse",
    "ListVirtualAccountResponse",
    "ListWorkspacesResponse",
    "LoadBalanceTarget",
    "LoadBalancingConfig",
    "LoadBalancingRule",
    "LoadBalancingWhen",
    "LocalArtifactSource",
    "LocalModelSource",
    "LocalSource",
    "Log",
    "LogsFilterQuery",
    "LogsFilterQueryType",
    "LogsResponse",
    "LogsSearchFilterType",
    "LogsSearchOperatorType",
    "LogsSortingDirection",
    "Manual",
    "McpServerAuth",
    "McpServerHeaderAuth",
    "McpServerHeaderOverrideAuth",
    "McpServerIntegration",
    "McpServerIntegrationTransport",
    "McpServerIntegrations",
    "McpServerOAuth2",
    "McpServerOAuth2JwtSource",
    "McpServerPassthrough",
    "McpServerProviderAccount",
    "McpServerToolDetails",
    "McpServerWithFqn",
    "McpServerWithUrl",
    "McpTool",
    "Metadata",
    "Metric",
    "MimeType",
    "MirrorAction",
    "MistralAiIntegrations",
    "MistralAiKeyAuth",
    "MistralAiModel",
    "MistralAiProviderAccount",
    "MlRepo",
    "MlRepoManifest",
    "Model",
    "ModelConfiguration",
    "ModelCostMetric",
    "ModelManifest",
    "ModelManifestFramework",
    "ModelManifestSource",
    "ModelProviderAccount",
    "ModelType",
    "ModelVersion",
    "ModelVersionEnvironment",
    "MultiPartUpload",
    "MultiPartUploadResponse",
    "MultiPartUploadStorageProvider",
    "NatsInputConfig",
    "NatsMetricConfig",
    "NatsOutputConfig",
    "NatsUserPasswordAuth",
    "NodeSelector",
    "NodeSelectorCapacityType",
    "Nodepool",
    "NodepoolSelector",
    "NomicIntegrations",
    "NomicKeyAuth",
    "NomicModel",
    "NomicProviderAccount",
    "NonNegativeFloat",
    "Notebook",
    "NotebookConfig",
    "NotificationTarget",
    "NotificationTargetForAlertRule",
    "NvidiaGpu",
    "NvidiaMiggpu",
    "NvidiaMiggpuProfile",
    "NvidiaTimeslicingGpu",
    "OAuth2LoginProvider",
    "OciRepo",
    "OllamaIntegrations",
    "OllamaKeyAuth",
    "OllamaModel",
    "OllamaProviderAccount",
    "OnnxFramework",
    "OpenAiIntegrations",
    "OpenAiModel",
    "OpenAiModerationsGuardrailConfig",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValue",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment",
    "OpenRouterApiKeyAuth",
    "OpenRouterIntegrations",
    "OpenRouterModel",
    "OpenRouterProviderAccount",
    "OpenaiApiKeyAuth",
    "OpenaiProviderAccount",
    "Operation",
    "OtelExporterGrpcConfig",
    "OtelExporterHttpConfig",
    "OtelExporterHttpConfigEncoding",
    "OwnedBy",
    "PaddleFramework",
    "PagerDuty",
    "PagerDutyIntegration",
    "PagerDutyIntegrationKeyAuth",
    "PagerDutyIntegrations",
    "PagerDutyProviderAccount",
    "Pagination",
    "PalmIntegrations",
    "PalmKeyAuth",
    "PalmModel",
    "PalmProviderAccount",
    "PaloAltoPrismaAirsGuardrailConfig",
    "PaloAltoPrismaAirsGuardrailConfigMode",
    "PaloAltoPrismaAirsKeyAuth",
    "PangeaGuardType",
    "PangeaGuardrailConfig",
    "PangeaGuardrailConfigOperation",
    "PangeaKeyAuth",
    "Param",
    "ParamParamType",
    "Parameters",
    "ParametersStop",
    "PatronusAnswerRelevanceCriteria",
    "PatronusAnswerRelevanceEvaluator",
    "PatronusEvaluator",
    "PatronusGliderCriteria",
    "PatronusGliderEvaluator",
    "PatronusGuardrailConfig",
    "PatronusGuardrailConfigTarget",
    "PatronusJudgeCriteria",
    "PatronusJudgeEvaluator",
    "PatronusKeyAuth",
    "PatronusPhiCriteria",
    "PatronusPhiEvaluator",
    "PatronusPiiCriteria",
    "PatronusPiiEvaluator",
    "PatronusToxicityCriteria",
    "PatronusToxicityEvaluator",
    "PerThousandEmbeddingTokensCostMetric",
    "PerThousandTokensCostMetric",
    "Permissions",
    "PerplexityAiKeyAuth",
    "PerplexityAiModel",
    "PerplexityAiProviderAccount",
    "PerplexityIntegrations",
    "PersonalAccessTokenManifest",
    "Pip",
    "Poetry",
    "PolicyActions",
    "PolicyEntityTypes",
    "PolicyFilters",
    "PolicyManifest",
    "PolicyManifestMode",
    "PolicyManifestOperation",
    "PolicyMutationOperation",
    "PolicyValidationOperation",
    "Port",
    "PortAppProtocol",
    "PortAuth",
    "PortProtocol",
    "PresignedUrlObject",
    "PriorityBasedLoadBalanceTarget",
    "PriorityBasedLoadBalancing",
    "PriorityBasedLoadBalancingRule",
    "PrometheusAlertRule",
    "Prompt",
    "PromptFooGuardType",
    "PromptFooGuardrailConfig",
    "PromptFooGuardrailConfigOperation",
    "PromptVersion",
    "ProviderAccounts",
    "PublicCostMetric",
    "PySparkTaskConfig",
    "PyTorchFramework",
    "PythonBuild",
    "PythonBuildCommand",
    "PythonBuildPythonDependencies",
    "PythonTaskConfig",
    "PythonTaskConfigImage",
    "PythonTaskConfigMountsItem",
    "QuayArtifactsRegistry",
    "QuayBasicAuth",
    "QuayIntegrations",
    "QuayProviderAccount",
    "QuerySpansResponse",
    "RStudio",
    "RateLimitConfig",
    "RateLimitRule",
    "RateLimitUnit",
    "RateLimitWhen",
    "Recommendation",
    "RefusalContentPart",
    "RegisterUsersResponse",
    "RemoteSource",
    "Resources",
    "ResourcesDevicesItem",
    "ResourcesNode",
    "RetryConfig",
    "RevokeAllPersonalAccessTokenResponse",
    "RoleManifest",
    "RolePermissions",
    "Rolling",
    "RpsMetric",
    "SagemakerModel",
    "SambaNovaIntegrations",
    "SambaNovaKeyAuth",
    "SambaNovaModel",
    "SambaNovaProviderAccount",
    "Schedule",
    "ScheduleConcurrencyPolicy",
    "Secret",
    "SecretGroup",
    "SecretGroupManifest",
    "SecretInput",
    "SecretMount",
    "SecretStoreConfig",
    "SecretVersion",
    "SelfHostedModel",
    "SelfHostedModelAuthData",
    "SelfHostedModelIntegrations",
    "SelfHostedModelModelServer",
    "SelfHostedModelProviderAccount",
    "Service",
    "ServiceAutoscaling",
    "ServiceAutoscalingMetrics",
    "ServiceReplicas",
    "ServiceRolloutStrategy",
    "Session",
    "SignedUrl",
    "SklearnFramework",
    "SklearnModelSchema",
    "SklearnSerializationFormat",
    "SlaCutoff",
    "SlackBot",
    "SlackBotAuth",
    "SlackBotIntegration",
    "SlackIntegrations",
    "SlackProviderAccount",
    "SlackWebhook",
    "SlackWebhookAuth",
    "SlackWebhookIntegration",
    "SmtpCredentials",
    "SnowflakeCortexIntegrations",
    "SnowflakeCortexModel",
    "SnowflakeCortexPatTokenAuth",
    "SnowflakeCortexProviderAccount",
    "SortDirection",
    "SpaCyFramework",
    "SpanAttributeFilter",
    "SpanAttributeFilterOperator",
    "SpanAttributeFilterValue",
    "SpanFieldFilter",
    "SpanFieldFilterOperator",
    "SpanFieldFilterSpanFieldName",
    "SpanFieldFilterValue",
    "SparkBuild",
    "SparkConfig",
    "SparkDriverConfig",
    "SparkExecutorConfig",
    "SparkExecutorConfigInstances",
    "SparkExecutorDynamicScaling",
    "SparkExecutorFixedInstances",
    "SparkImage",
    "SparkImageBuild",
    "SparkImageBuildBuildSource",
    "SparkJob",
    "SparkJobEntrypoint",
    "SparkJobImage",
    "SparkJobJavaEntrypoint",
    "SparkJobPythonEntrypoint",
    "SparkJobPythonNotebookEntrypoint",
    "SparkJobScalaEntrypoint",
    "SparkJobScalaNotebookEntrypoint",
    "SparkJobTriggerInput",
    "SqsInputConfig",
    "SqsOutputConfig",
    "SqsQueueMetricConfig",
    "SqsQueueMetricConfigAuth",
    "SshServer",
    "SshServerConfig",
    "SsoTeamManifest",
    "StageArtifactResponse",
    "StaticVolumeConfig",
    "StatsModelsFramework",
    "StringDataMount",
    "Subject",
    "SubjectType",
    "SyncTokenInSecretStoreInfo",
    "SyncVirtualAccountTokenResponse",
    "SystemMessage",
    "SystemMessageContent",
    "TaskDockerFileBuild",
    "TaskPySparkBuild",
    "TaskPythonBuild",
    "Team",
    "TeamManifest",
    "TeamOwnedBy",
    "TensorFlowFramework",
    "TerminateJobResponse",
    "TextContentPart",
    "TextContentPartText",
    "TogetherAiIntegrations",
    "TogetherAiKeyAuth",
    "TogetherAiModel",
    "TogetherAiProviderAccount",
    "TokenPagination",
    "ToolCall",
    "ToolMessage",
    "ToolMessageContent",
    "ToolSchema",
    "TraceSpan",
    "TracingProject",
    "TracingProjectManifest",
    "TransformersFramework",
    "TriggerJobRunResponse",
    "TrueFoundryApplyRequestManifest",
    "TrueFoundryApplyResponse",
    "TrueFoundryApplyResponseAction",
    "TrueFoundryApplyResponseExistingManifest",
    "TrueFoundryArtifactSource",
    "TrueFoundryDbssm",
    "TrueFoundryDeleteRequestManifest",
    "TrueFoundryIntegrations",
    "TrueFoundryInteractiveLogin",
    "TrueFoundryManagedSource",
    "TrueFoundryProviderAccount",
    "TtlIntegrations",
    "TtlProviderAccount",
    "TtlRegistry",
    "UpdateSecretInput",
    "UpdateUserRolesResponse",
    "UpgradeData",
    "UsageCodeSnippet",
    "User",
    "UserMessage",
    "UserMessageContent",
    "UserMessageContentOneItem",
    "UserMetadata",
    "UserMetadataTenantRoleManagedBy",
    "UserResource",
    "UserRoleWithResource",
    "UserRoleWithResourceResourceType",
    "Uv",
    "ValidationError",
    "ValidationErrorLocItem",
    "VertexModel",
    "VirtualAccount",
    "VirtualAccountManifest",
    "VirtualAccountOwnedBy",
    "VirtualMcpServerIntegration",
    "VirtualMcpServerSource",
    "VirtualModel",
    "VirtualModelProviderAccount",
    "Volume",
    "VolumeBrowser",
    "VolumeConfig",
    "VolumeMount",
    "WebhookBasicAuth",
    "WebhookBearerAuth",
    "WebhookIntegration",
    "WebhookIntegrationAuthData",
    "WebhookIntegrations",
    "WebhookProviderAccount",
    "WeightBasedLoadBalancing",
    "WeightBasedLoadBalancingRule",
    "WorkbenchImage",
    "WorkerConfig",
    "WorkerConfigInputConfig",
    "WorkerConfigOutputConfig",
    "Workflow",
    "WorkflowAlert",
    "WorkflowFlyteEntitiesItem",
    "WorkflowSource",
    "Workspace",
    "WorkspaceManifest",
    "XgBoostFramework",
    "XgBoostModelSchema",
    "XgBoostSerializationFormat",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .azure_content_safety_category import AzureContentSafetyCategory
from .azure_key_auth import AzureKeyAuth


class AzureContentSafetyGuardrailConfig(UniversalBaseModel):
    """
    Azure Content Safety
    """

    name: str = pydantic.Field()
    """
    The name of the Guardrail Config.
    """

    type: typing.Literal["integration/guardrail-config/azure-content-safety"] = pydantic.Field(
        default="integration/guardrail-config/azure-content-safety"
    )
    """
    +uiType=Hidden
    +value=integration/guardrail-config/azure-content-safety
    """

    resource_name: str = pydantic.Field()
    """
    Name of your Azure Content Safety resource where the service is deployed (e.g., my-content-safety)
    """

    api_version: str = pydantic.Field(default="2024-09-01")
    """
    API version for the Content Safety API
    """

    custom_host: typing.Optional[str] = pydantic.Field(default=None)
    """
    Custom endpoint URL for the Content Safety API (optional, uses default Azure endpoint if not specified)
    """

    operation: typing.Optional[typing.Literal["validate"]] = pydantic.Field(default=None)
    """
    The operation type for this guardrail. Azure Content Safety guardrails can only be used for validation.
    """

    blocklist_names: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Names of custom blocklists created in Azure Content Safety to check text against. Leave empty if not using custom blocklists
    """

    severity_threshold: float = pydantic.Field(default=2.0)
    """
    Minimum severity level (0-6) to flag content. Higher values are more restrictive. 0=Safe, 2=Low risk, 4=Medium risk, 6=High risk
    """

    categories: typing.List[AzureContentSafetyCategory] = pydantic.Field()
    """
    Types of harmful content to detect: Hate (hate speech), SelfHarm (self-injury), Sexual (sexual content), Violence (violent content)
    """

    auth_data: AzureKeyAuth

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .blob_storage_reference import BlobStorageReference
from .user_message_content_one_item import UserMessageContentOneItem

UserMessageContent = typing.Union[str, typing.List[UserMessageContentOneItem], BlobStorageReference]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pagination import AsyncPager, SyncPager
from ..core.request_options import RequestOptions
from ..types.get_workspace_response import GetWorkspaceResponse
from ..types.list_workspaces_response import ListWorkspacesResponse
from ..types.workspace import Workspace
from ..types.workspace_manifest import WorkspaceManifest
from .raw_client import AsyncRawWorkspacesClient, RawWorkspacesClient
from .types.workspaces_delete_response import WorkspacesDeleteResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WorkspacesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWorkspacesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWorkspacesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWorkspacesClient
        """
        return self._raw_client

    def list(
        self,
        *,
        limit: typing.Optional[int] = 100,
        offset: typing.Optional[int] = 0,
        cluster_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        fqn: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[Workspace, ListWorkspacesResponse]:
        """
        List workspaces associated with the user. Optional filters include clusterId, fqn, and workspace name. Pagination is available based on query parameters.

        Parameters
        ----------
        limit : typing.Optional[int]
            Number of items per page

        offset : typing.Optional[int]
            Number of items to skip

        cluster_id : typing.Optional[str]
            ClusterId of the Cluster

        name : typing.Optional[str]
            Workspace Name

        fqn : typing.Optional[str]
            Workspace FQN

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[Workspace, ListWorkspacesResponse]
            Returns all the workspaces associated with a user and also the response includes paginated data.

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        response = client.workspaces.list(
            limit=10,
            offset=0,
            cluster_id="clusterId",
            name="name",
            fqn="fqn",
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            limit=limit, offset=offset, cluster_id=cluster_id, name=name, fqn=fqn, request_options=request_options
        )

    def create_or_update(
        self,
        *,
        manifest: WorkspaceManifest,
        dry_run: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetWorkspaceResponse:
        """
        Creates a new workspace or updates an existing one based on the provided manifest.

        Parameters
        ----------
        manifest : WorkspaceManifest
            Workspace manifest

        dry_run : typing.Optional[bool]
            Dry run the request

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetWorkspaceResponse
            - Creates or updates a workspace with given manifest
                - Corresponding authorization entry with admin role is made using newly created workspace
                - Attached with the cluster id where the workspace is created

        Examples
        --------
        from truefoundry_sdk import TrueFoundry, WorkspaceManifest

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.workspaces.create_or_update(
            manifest=WorkspaceManifest(
                cluster_fqn="cluster_fqn",
                name="name",
            ),
        )
        """
        _response = self._raw_client.create_or_update(
            manifest=manifest, dry_run=dry_run, request_options=request_options
        )
        return _response.data

    def get(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> GetWorkspaceResponse:
        """
        Get workspace associated with provided workspace id

        Parameters
        ----------
        id : str
            Workspace id of the space

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetWorkspaceResponse
            Returns the workspaces associated with provided workspace id

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.workspaces.get(
            id="id",
        )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> WorkspacesDeleteResponse:
        """
        Deletes the workspace with the given workspace ID.
            - Removes the associated namespace from the cluster.
            - Deletes the corresponding authorization entry.

        Parameters
        ----------
        id : str
            Workspace id of the space

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspacesDeleteResponse
            Successfully deletes the workspace and returns the workspace details along with a confirmation message.

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.workspaces.delete(
            id="id",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data


class AsyncWorkspacesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWorkspacesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWorkspacesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWorkspacesClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        limit: typing.Optional[int] = 100,
        offset: typing.Optional[int] = 0,
        cluster_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        fqn: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[Workspace, ListWorkspacesResponse]:
        """
        List workspaces associated with the user. Optional filters include clusterId, fqn, and workspace name. Pagination is available based on query parameters.

        Parameters
        ----------
        limit : typing.Optional[int]
            Number of items per page

        offset : typing.Optional[int]
            Number of items to skip

        cluster_id : typing.Optional[str]
            ClusterId of the Cluster

        name : typing.Optional[str]
            Workspace Name

        fqn : typing.Optional[str]
            Workspace FQN

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[Workspace, ListWorkspacesResponse]
            Returns all the workspaces associated with a user and also the response includes paginated data.

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            response = await client.workspaces.list(
                limit=10,
                offset=0,
                cluster_id="clusterId",
                name="name",
                fqn="fqn",
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            limit=limit, offset=offset, cluster_id=cluster_id, name=name, fqn=fqn, request_options=request_options
        )

    async def create_or_update(
        self,
        *,
        manifest: WorkspaceManifest,
        dry_run: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetWorkspaceResponse:
        """
        Creates a new workspace or updates an existing one based on the provided manifest.

        Parameters
        ----------
        manifest : WorkspaceManifest
            Workspace manifest

        dry_run : typing.Optional[bool]
            Dry run the request

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetWorkspaceResponse
            - Creates or updates a workspace with given manifest
                - Corresponding authorization entry with admin role is made using newly created workspace
                - Attached with the cluster id where the workspace is created

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry, WorkspaceManifest

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.workspaces.create_or_update(
                manifest=WorkspaceManifest(
                    cluster_fqn="cluster_fqn",
                    name="name",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_or_update(
            manifest=manifest, dry_run=dry_run, request_options=request_options
        )
        return _response.data

    async def get(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> GetWorkspaceResponse:
        """
        Get workspace associated with provided workspace id

        Parameters
        ----------
        id : str
            Workspace id of the space

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetWorkspaceResponse
            Returns the workspaces associated with provided workspace id

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.workspaces.get(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkspacesDeleteResponse:
        """
        Deletes the workspace with the given workspace ID.
            - Removes the associated namespace from the cluster.
            - Deletes the corresponding authorization entry.

        Parameters
        ----------
        id : str
            Workspace id of the space

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WorkspacesDeleteResponse
            Successfully deletes the workspace and returns the workspace details along with a confirmation message.

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.workspaces.delete(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CustomTlsSettings(UniversalBaseModel):
    """
    Configure TLS settings for secure connections with custom CA certificates.
    """

    reject_unauthorized: bool = pydantic.Field(default=True)
    """
    When set to true, it will reject any connection which is not authorized with the list of supplied CAs.
    """

    ca_cert: typing.Optional[str] = pydantic.Field(default=None)
    """
    Add custom CA certificates to use for TLS verification.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OtelExporterGrpcConfig(UniversalBaseModel):
    """
    gRPC Configuration
    """

    type: typing.Literal["grpc"] = pydantic.Field(default="grpc")
    """
    Configuration type
    """

    endpoint: str = pydantic.Field()
    """
    Traces endpoint URL where OpenTelemetry data will be sent (format: https://<host>:<port>)
    """

    headers: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    gRPC metadata to include in OpenTelemetry export requests
    """

    additional_resource_attributes: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Set additional attributes to append them to existing resource attributes of every exported trace
    """

    exclude_request_data: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Enable to prevent forwarding the LLM or MCP request and response body in exported traces. The following span attributes are dropped: tfy.input, tfy.output, tfy.input_short_hand
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.apply_ml_entity_response import ApplyMlEntityResponse
from ...types.empty_response import EmptyResponse
from .raw_client import AsyncRawMlClient, RawMlClient
from .types.apply_ml_entity_request_manifest import ApplyMlEntityRequestManifest
from .types.delete_ml_entity_request_manifest import DeleteMlEntityRequestManifest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class MlClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMlClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawMlClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMlClient
        """
        return self._raw_client

    def apply(
        self, *, manifest: ApplyMlEntityRequestManifest, request_options: typing.Optional[RequestOptions] = None
    ) -> ApplyMlEntityResponse:
        """
        Parameters
        ----------
        manifest : ApplyMlEntityRequestManifest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ApplyMlEntityResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import ModelManifest, TrueFoundry, TrueFoundryManagedSource

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.internal.ml.apply(
            manifest=ModelManifest(
                name="name",
                metadata={"key": "value"},
                ml_repo="ml_repo",
                source=TrueFoundryManagedSource(),
            ),
        )
        """
        _response = self._raw_client.apply(manifest=manifest, request_options=request_options)
        return _response.data

    def delete(
        self, *, manifest: DeleteMlEntityRequestManifest, request_options: typing.Optional[RequestOptions] = None
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        manifest : DeleteMlEntityRequestManifest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import ModelManifest, TrueFoundry, TrueFoundryManagedSource

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.internal.ml.delete(
            manifest=ModelManifest(
                name="name",
                metadata={"key": "value"},
                ml_repo="ml_repo",
                source=TrueFoundryManagedSource(),
            ),
        )
        """
        _response = self._raw_client.delete(manifest=manifest, request_options=request_options)
        return _response.data


class AsyncMlClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMlClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawMlClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMlClient
        """
        return self._raw_client

    async def apply(
        self, *, manifest: ApplyMlEntityRequestManifest, request_options: typing.Optional[RequestOptions] = None
    ) -> ApplyMlEntityResponse:
        """
        Parameters
        ----------
        manifest : ApplyMlEntityRequestManifest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ApplyMlEntityResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import (
            AsyncTrueFoundry,
            ModelManifest,
            TrueFoundryManagedSource,
        )

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.internal.ml.apply(
                manifest=ModelManifest(
                    name="name",
                    metadata={"key": "value"},
                    ml_repo="ml_repo",
                    source=TrueFoundryManagedSource(),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.apply(manifest=manifest, request_options=request_options)
        return _response.data

    async def delete(
        self, *, manifest: DeleteMlEntityRequestManifest, request_options: typing.Optional[RequestOptions] = None
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        manifest : DeleteMlEntityRequestManifest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import (
            AsyncTrueFoundry,
            ModelManifest,
            TrueFoundryManagedSource,
        )

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.internal.ml.delete(
                manifest=ModelManifest(
                    name="name",
                    metadata={"key": "value"},
                    ml_repo="ml_repo",
                    source=TrueFoundryManagedSource(),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(manifest=manifest, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class LogsSearchFilterType(enum.StrEnum):
    """
    Query filter type for logs search
    """

    REGEX = "regex"
    SUBSTRING = "substring"
    IGNORE_CASE_SUBSTRING = "ignore_case_substring"

    def visit(
        self,
        regex: typing.Callable[[], T_Result],
        substring: typing.Callable[[], T_Result],
        ignore_case_substring: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LogsSearchFilterType.REGEX:
            return regex()
        if self is LogsSearchFilterType.SUBSTRING:
            return substring()
        if self is LogsSearchFilterType.IGNORE_CASE_SUBSTRING:
            return ignore_case_substring()



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.not_found_error import NotFoundError


class RawInternalClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_id_from_fqn(
        self, type: str, *, fqn: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[typing.Dict[str, typing.Any]]:
        """
        Get IDs associated with the FQN for various entity types, such as deployment, application, workspace, or cluster.

        Parameters
        ----------
        type : str
            Entity Type

        fqn : str
            Entity FQN

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Dict[str, typing.Any]]
            Returns the IDs for the specified entity type based on the provided FQN. For example, deploymentId, applicationId, and workspaceId for type deployment, or applicationId and workspaceId for type app.
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/svc/v1/fqn/{jsonable_encoder(type)}",
            method="GET",
            params={
                "fqn": fqn,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawInternalClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_id_from_fqn(
        self, type: str, *, fqn: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[typing.Dict[str, typing.Any]]:
        """
        Get IDs associated with the FQN for various entity types, such as deployment, application, workspace, or cluster.

        Parameters
        ----------
        type : str
            Entity Type

        fqn : str
            Entity FQN

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Dict[str, typing.Any]]
            Returns the IDs for the specified entity type based on the provided FQN. For example, deploymentId, applicationId, and workspaceId for type deployment, or applicationId and workspaceId for type app.
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/svc/v1/fqn/{jsonable_encoder(type)}",
            method="GET",
            params={
                "fqn": fqn,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Dict[str, typing.Any],
                    parse_obj_as(
                        type_=typing.Dict[str, typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class BudgetLimitUnit(enum.StrEnum):
    """
    Unit for budget limit calculation
    """

    COST_PER_DAY = "cost_per_day"
    COST_PER_MONTH = "cost_per_month"
    COST_PER_WEEK = "cost_per_week"
    TOKENS_PER_DAY = "tokens_per_day"
    TOKENS_PER_MONTH = "tokens_per_month"

    def visit(
        self,
        cost_per_day: typing.Callable[[], T_Result],
        cost_per_month: typing.Callable[[], T_Result],
        cost_per_week: typing.Callable[[], T_Result],
        tokens_per_day: typing.Callable[[], T_Result],
        tokens_per_month: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is BudgetLimitUnit.COST_PER_DAY:
            return cost_per_day()
        if self is BudgetLimitUnit.COST_PER_MONTH:
            return cost_per_month()
        if self is BudgetLimitUnit.COST_PER_WEEK:
            return cost_per_week()
        if self is BudgetLimitUnit.TOKENS_PER_DAY:
            return tokens_per_day()
        if self is BudgetLimitUnit.TOKENS_PER_MONTH:
            return tokens_per_month()
